(function () {
    'use strict';
    angular.module('ionic-ratings', ['ionic'])
        .directive('ionicRatings', ionicRatings);

    function ionicRatings() {
        return {
            restrict: 'AE',
            replace: true,
            template: '<div class="text-center ionic_ratings">' +
            '<span class="icon {{iconOff}} ionic_rating_icon_off" ng-style="iconOffColor" ng-click="ratingsClicked(1)" ng-show="rating < 1" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOn}} ionic_rating_icon_on" ng-style="iconOnColor" ng-click="ratingsUnClicked(1)" ng-show="rating > 0" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOff}} ionic_rating_icon_off" ng-style="iconOffColor" ng-click="ratingsClicked(2)" ng-show="rating < 2" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOn}} ionic_rating_icon_on" ng-style="iconOnColor" ng-click="ratingsUnClicked(2)" ng-show="rating > 1" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOff}} ionic_rating_icon_off" ng-style="iconOffColor" ng-click="ratingsClicked(3)" ng-show="rating < 3" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOn}} ionic_rating_icon_on" ng-style="iconOnColor" ng-click="ratingsUnClicked(3)" ng-show="rating > 2" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOff}} ionic_rating_icon_off" ng-style="iconOffColor" ng-click="ratingsClicked(4)" ng-show="rating < 4" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOn}} ionic_rating_icon_on" ng-style="iconOnColor" ng-click="ratingsUnClicked(4)" ng-show="rating > 3" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOff}} ionic_rating_icon_off" ng-style="iconOffColor" ng-click="ratingsClicked(5)" ng-show="rating < 5" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '<span class="icon {{iconOn}} ionic_rating_icon_on" ng-style="iconOnColor" ng-click="ratingsUnClicked(5)" ng-show="rating > 4" ng-class="{\'read_only\':(readOnly)}"></span>' +
            '</div>',
            scope: {
                ratingsObj: '=ratingsobj'
            },
            link: function (scope, element, attrs) {

                //Setting the default values, if they are not passed
                scope.iconOn = scope.ratingsObj.iconOn || 'ion-ios-star';
                scope.iconOff = scope.ratingsObj.iconOff || 'ion-ios-star-outline';
                scope.iconOnColor = scope.ratingsObj.iconOnColor || 'rgb(200, 200, 100)';
                scope.iconOffColor = scope.ratingsObj.iconOffColor || 'rgb(200, 100, 100)';
                scope.rating = scope.ratingsObj.rating || 0;
                scope.minRating = scope.ratingsObj.minRating || 0;
                scope.readOnly = scope.ratingsObj.readOnly || false;
                scope.ratingsObj.reset = function () {
                    scope.rating = 0;
                };
                scope.ratingsObj.setRating = function (newRating) {
                    scope.rating = newRating;
                };

                //Setting the color for the icon, when it is active
                scope.iconOnColor = {
                    color: scope.iconOnColor
                };

                //Setting the color for the icon, when it is not active
                scope.iconOffColor = {
                    color: scope.iconOffColor
                };

                //Setting the rating
                scope.rating = (scope.rating > scope.minRating) ? scope.rating : scope.minRating;

                //Setting the previously selected rating
                scope.prevRating = 0;

                //Called when he user clicks on the rating
                scope.ratingsClicked = function (val) {

                    if (!scope.readOnly) {
                        if (scope.minRating !== 0 && val < scope.minRating) {
                            scope.rating = scope.minRating;
                        } else if (!scope.readOnly) {
                            scope.rating = val;
                        }
                        //scope.prevRating = val;
                        scope.ratingsObj.callback(scope.rating);
                    }

                };

                //Called when he user un clicks on the rating
                scope.ratingsUnClicked = function (val) {
                    if (!scope.readOnly) {
                        if (scope.minRating !== 0 && val < scope.minRating) {
                            scope.rating = scope.minRating;
                        } else {
                            scope.rating = val;
                        }
                        if (scope.prevRating == val) {
                            if (scope.minRating !== 0) {
                                scope.rating = scope.minRating;
                            } else {
                                scope.rating = 0;
                            }
                        }
                        scope.prevRating = val;
                        scope.ratingsObj.callback(scope.rating);
                    }

                };

            }
        }
    }

})();



angular.module('mPOWER.controllers', ['ionic', 'ngCordova', 'ionic-ratings', 'ion-autocomplete', 'angular.filter'])

    .filter('unique', function () {

        return function (items, filterOn) {

            if (filterOn === false) {
                return items;
            }

            if ((filterOn || angular.isUndefined(filterOn)) && angular.isArray(items)) {
                var hashCheck = {}, newItems = [];

                var extractValueToCompare = function (item) {
                    if (angular.isObject(item) && angular.isString(filterOn)) {
                        return item[filterOn];
                    } else {
                        return item;
                    }
                };

                angular.forEach(items, function (item) {
                    var valueToCheck, isDuplicate = false;

                    for (var i = 0; i < newItems.length; i++) {
                        if (angular.equals(extractValueToCompare(newItems[i]), extractValueToCompare(item))) {
                            isDuplicate = true;
                            break;
                        }
                    }
                    if (!isDuplicate) {
                        newItems.push(item);
                    }

                });
                items = newItems;
            }
            return items;
        };
    })

    .filter('INR', function () {
        return function (input) {
            if (!isNaN(input)) {
                //var output = Number(input).toLocaleString('en-IN');   <-- This method is not working fine in all browsers!           
                var result = input.toString().split('.');

                var lastThree = result[0].substring(result[0].length - 3);
                var otherNumbers = result[0].substring(0, result[0].length - 3);
                if (otherNumbers != '')
                    lastThree = ',' + lastThree;
                var output = otherNumbers.replace(/\B(?=(\d{2})+(?!\d))/g, ",") + lastThree;

                /*
                 if (result.length > 1) {
                 output += "." + result[1];
                 }
                 */

                return output;
            }
        }
    })

    .controller('MainController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform,
        userService, $ionicModal, $ionicPopup, $window) {



        $ionicPlatform.onHardwareBackButton(function () {
            $ionicLoading.hide();
            var preView = userService.getpreviousView();
            //alert(preView);
            $state.go(preView);
        });

        $scope.ratings = {
            TOTAL_FEEDBACK: 0,
            AVGRATING: 0,
            PRODUCT_QUALITY: 0,
            QUANTITY_DELIVERED: 0,
            SERVICE: 0,
            FACILITIES: 0,
            CLEANINESS: 0,
            CLEANTOILET: 0
        };

        $scope.dsr = {
            LY_MS: 0,
            MS_TARGET: 0,
            PRORATA_LY_MS: 0,
            PRORATA_TARGET_MS: 0,
            CURRENT_MS: 0,
            CURRENT_MS_PERC: 0,
            TARGET_MS_PERC: 0,
            BALANCE_MS: 0,
            LY_HSD: 0,
            HSD_TARGET: 0,
            PRORATA_LY_HSD: 0,
            PRORATA_TARGET_HSD: 0,
            CURRENT_HSD: 0,
            CURRENT_HSD_PERC: 0,
            TARGET_HSD_PERC: 0,
            BALANCE_HSD: 0
        };



        $scope.settings = {
            lang: $scope.language,
            OldPswd: "",
            NewPswrd: "",
            CPswrd: ""
        };


        $scope.rating_AR_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.AVGRATING,
            minRating: 0,
            readOnly: true
        };

        $scope.rating_AR1_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.AVGRATING,
            minRating: 0,
            readOnly: true
        };

        $scope.rating_PQ_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.PRODUCT_QUALITY,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_QD_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.QUANTITY_DELIVERED,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_S_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.SERVICE,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_CL_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.CLEANINESS,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_F_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.FACILITIES,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_CT_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.CLEANTOILET,
            minRating: 0,
            readOnly: true
        };







        $scope.$on('$ionicView.enter', function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $scope.employee = userService.getUser();
            $scope.tabNumber = 1;
            //initiLiseValues();
            loadRatings();
            loadDSR();
            //$ionicLoading.hide();
        });

        $scope.openLinks = function (url) {
            window.open(url, '_system', 'location=no');
        }


        function loadDSR() {
            var serviceDetails = {};
            var empRole = $scope.employee.empRole;
            if (empRole == "FO-RS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSdsrSG";
                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.paramName = $scope.employee.salesArea;
                serviceDetails.paramValue = $scope.employee.salesGroup;
                serviceDetails.arrayName = "dbDSRSGOutput";
            } else if (empRole == "DO-RS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSdsrDO";
                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "dbDSRDOOutput";
            } else if (empRole == "SO-RS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSoDSR";
                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "dbSOdsrOutput";
            } else if (empRole == "HO-RS" || empRole == "IS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSHoDSR";
                serviceDetails.paramKey = "";
                serviceDetails.empHier = "HO";
                serviceDetails.paramName = "All India";
                serviceDetails.paramValue = "";
                serviceDetails.arrayName = "HORatingOutput";
            }


            userService.setServiceDetails(serviceDetails);

            $scope.serviceDetails = userService.getServiceDetails();

            $http.get(serviceDetails.url + "?" + serviceDetails.paramKey + "=" + serviceDetails.paramValue)
                .success(function (data, status) {
                    if (data) {

                        if (empRole == "HO-RS" || empRole == "IS") {
                            $scope.dsr.LY_MS = data.LY_MS;
                            $scope.dsr.MS_TARGET = data.MS_TARGET;
                            $scope.dsr.PRORATA_LY_MS = data.PRORATA_LY_MS;
                            $scope.dsr.PRORATA_TARGET_MS = data.PRORATA_TARGET_MS;
                            $scope.dsr.CURRENT_MS = data.CURRENT_MS;
                            if (data.PRORATA_LY_MS > 0) {
                                $scope.dsr.CURRENT_MS_PERC = (((data.CURRENT_MS - data.PRORATA_LY_MS) / data.PRORATA_LY_MS) * 100).toFixed(2);
                            }
                            if (data.PRORATA_TARGET_MS > 0) {
                                $scope.dsr.TARGET_MS_PERC = (((data.CURRENT_MS - data.PRORATA_TARGET_MS) / data.PRORATA_TARGET_MS) * 100).toFixed(2);
                            }
                            $scope.dsr.BALANCE_MS = data.BALANCE_MS;

                            $scope.dsr.LY_HSD = data.LY_HSD;
                            $scope.dsr.HSD_TARGET = data.HSD_TARGET;
                            $scope.dsr.PRORATA_LY_HSD = data.PRORATA_LY_HSD;
                            $scope.dsr.PRORATA_TARGET_HSD = data.PRORATA_TARGET_HSD;
                            $scope.dsr.CURRENT_HSD = data.CURRENT_HSD;
                            if (data.PRORATA_LY_HSD > 0) {
                                $scope.dsr.CURRENT_HSD_PERC = (((data.CURRENT_HSD - data.PRORATA_LY_HSD) / data.PRORATA_LY_HSD) * 100).toFixed(2);
                            }
                            if (data.PRORATA_TARGET_HSD > 0) {
                                $scope.dsr.TARGET_HSD_PERC = (((data.CURRENT_HSD - data.PRORATA_TARGET_HSD) / data.PRORATA_TARGET_HSD) * 100).toFixed(2);
                            }
                            $scope.dsr.BALANCE_HSD = data.BALANCE_HSD;
                        } else {
                            $scope.dsr.LY_MS = data[serviceDetails.arrayName][0].LY_MS;
                            $scope.dsr.MS_TARGET = data[serviceDetails.arrayName][0].MS_TARGET;
                            $scope.dsr.PRORATA_LY_MS = data[serviceDetails.arrayName][0].PRORATA_LY_MS;
                            $scope.dsr.PRORATA_TARGET_MS = data[serviceDetails.arrayName][0].PRORATA_TARGET_MS;
                            $scope.dsr.CURRENT_MS = data[serviceDetails.arrayName][0].CURRENT_MS;
                            if (data[serviceDetails.arrayName][0].PRORATA_LY_MS > 0) {
                                $scope.dsr.CURRENT_MS_PERC = (((data[serviceDetails.arrayName][0].CURRENT_MS - data[serviceDetails.arrayName][0].PRORATA_LY_MS) / data[serviceDetails.arrayName][0].PRORATA_LY_MS) * 100).toFixed(2);
                            }
                            if (data[serviceDetails.arrayName][0].PRORATA_TARGET_MS > 0) {
                                $scope.dsr.TARGET_MS_PERC = (((data[serviceDetails.arrayName][0].CURRENT_MS - data[serviceDetails.arrayName][0].PRORATA_TARGET_MS) / data[serviceDetails.arrayName][0].PRORATA_TARGET_MS) * 100).toFixed(2);
                            }
                            $scope.dsr.BALANCE_MS = data[serviceDetails.arrayName][0].BALANCE_MS;

                            $scope.dsr.LY_HSD = data[serviceDetails.arrayName][0].LY_HSD;
                            $scope.dsr.HSD_TARGET = data[serviceDetails.arrayName][0].HSD_TARGET;
                            $scope.dsr.PRORATA_LY_HSD = data[serviceDetails.arrayName][0].PRORATA_LY_HSD;
                            $scope.dsr.PRORATA_TARGET_HSD = data[serviceDetails.arrayName][0].PRORATA_TARGET_HSD;
                            $scope.dsr.CURRENT_HSD = data[serviceDetails.arrayName][0].CURRENT_HSD;
                            if (data[serviceDetails.arrayName][0].PRORATA_LY_HSD > 0) {
                                $scope.dsr.CURRENT_HSD_PERC = (((data[serviceDetails.arrayName][0].CURRENT_HSD - data[serviceDetails.arrayName][0].PRORATA_LY_HSD) / data[serviceDetails.arrayName][0].PRORATA_LY_HSD) * 100).toFixed(2);
                            }
                            if (data[serviceDetails.arrayName][0].PRORATA_TARGET_HSD > 0) {
                                $scope.dsr.TARGET_HSD_PERC = (((data[serviceDetails.arrayName][0].CURRENT_HSD - data[serviceDetails.arrayName][0].PRORATA_TARGET_HSD) / data[serviceDetails.arrayName][0].PRORATA_TARGET_HSD) * 100).toFixed(2);
                            }
                            $scope.dsr.BALANCE_HSD = data[serviceDetails.arrayName][0].BALANCE_HSD;
                        }

                        console.log(JSON.stringify($scope.dsr));
                        $scope.dsr.CURRENT_MS = $scope.dsr.CURRENT_MS.toFixed(0);
                        $scope.dsr.CURRENT_HSD = $scope.dsr.CURRENT_HSD.toFixed(0);
                    }

                    $ionicLoading.hide();
                }).error(onError);


        }


        function loadRatings() {
            var serviceDetails = {};
            var empRole = $scope.employee.empRole;
            if (empRole == "FO-RS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSgRating";
                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.paramName = $scope.employee.salesArea;
                serviceDetails.paramValue = $scope.employee.salesGroup;
                serviceDetails.arrayName = "SGRatingOutput";
            } else if (empRole == "DO-RS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSDoRating";
                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "DORatingOutput";
            } else if (empRole == "SO-RS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSoRating";
                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "SORatingOutput";
            } else if (empRole == "HO-RS" || empRole == "IS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSHoRating";
                serviceDetails.paramKey = "";
                serviceDetails.empHier = "HO";
                serviceDetails.paramName = "All India";
                serviceDetails.paramValue = "";
                serviceDetails.arrayName = "HORatingOutput";
            }


            userService.setServiceDetails(serviceDetails);

            $scope.serviceDetails = userService.getServiceDetails();

            $http.get(serviceDetails.url + "?" + serviceDetails.paramKey + "=" + serviceDetails.paramValue)
                .success(function (data, status) {
                    if (data) {
                        $scope.ratings = data[serviceDetails.arrayName][0];
                        if (JSON.stringify($scope.ratings.AVGRATING).indexOf("@nil") > -1) {
                            $scope.ratings.AVGRATING = "0";
                        }
                        if (JSON.stringify($scope.ratings.PRODUCT_QUALITY).indexOf("@nil") > -1) {
                            $scope.ratings.PRODUCT_QUALITY = "0";
                        }
                        if (JSON.stringify($scope.ratings.QUANTITY_DELIVERED).indexOf("@nil") > -1) {
                            $scope.ratings.QUANTITY_DELIVERED = "0";
                        }
                        if (JSON.stringify($scope.ratings.SERVICE).indexOf("@nil") > -1) {
                            $scope.ratings.SERVICE = "0";
                        }
                        if (JSON.stringify($scope.ratings.CLEANINESS).indexOf("@nil") > -1) {
                            $scope.ratings.CLEANINESS = "0";
                        }
                        if (JSON.stringify($scope.ratings.FACILITIES).indexOf("@nil") > -1) {
                            $scope.ratings.FACILITIES = "0";
                        }
                        if (JSON.stringify($scope.ratings.CLEANTOILET).indexOf("@nil") > -1) {
                            $scope.ratings.CLEANTOILET = "0";
                        }

                        $scope.rating_AR_Object.setRating(Math.floor($scope.ratings.AVGRATING));
                        $scope.rating_AR1_Object.setRating(Math.floor($scope.ratings.AVGRATING));
                        $scope.rating_PQ_Object.setRating(Math.floor($scope.ratings.PRODUCT_QUALITY));
                        $scope.rating_QD_Object.setRating(Math.floor($scope.ratings.QUANTITY_DELIVERED));
                        $scope.rating_S_Object.setRating(Math.floor($scope.ratings.SERVICE));
                        $scope.rating_CL_Object.setRating(Math.floor($scope.ratings.CLEANINESS));
                        $scope.rating_F_Object.setRating(Math.floor($scope.ratings.FACILITIES));
                        $scope.rating_CT_Object.setRating(Math.floor($scope.ratings.CLEANTOILET));
                    }

                    $ionicLoading.hide();
                }).error(onError);


        }

        function onError(data) {
            $scope.error = true;
            //alert("errror");
            $ionicLoading.hide();
        }

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }

        $scope.slideHasChanged = function (val) {

        }

        $scope.changeView = function (view) {
            userService.setpreviousView("app.home");
            $state.go(view);
        }

        //Modal window for filter
        $ionicModal.fromTemplateUrl('connectModal.html', function (modal) {
            $scope.socialModal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $scope.showSocialModal = function () {
            $scope.socialModal.show();
            var el = document.getElementById("socialLinks");
            el.classList.remove("fadeOutRight");

        }

        $ionicModal.fromTemplateUrl('ratingSummary.html', function (modal) {
            $scope.ratingModal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $ionicModal.fromTemplateUrl('dsrSummary.html', function (modal) {
            $scope.dsrModal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $scope.showRatingSummaryPop = function () {
            $scope.ratingModal.show();
        }

        $scope.hideRatingSummary = function () {
            $scope.ratingModal.hide();
        }

        $scope.showDSRPop = function () {
            $scope.dsrModal.show();
        }

        $scope.hideDSR = function () {
            $scope.dsrModal.hide();
        }

        $scope.hideSocialModal = function () {

            var el = document.getElementById("socialLinks");
            //el.classList.remove("my-class");
            el.classList.add("fadeOutRight");
            $timeout(function () {
                $scope.socialModal.hide();
            }, 400);

        }


        $ionicModal.fromTemplateUrl('empProfile.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $scope.hideLubeTips = function () {
            $scope.modal.hide();
        }

        $scope.showDProfile = function () {
            $scope.modal.show();
        }

        $scope.showRatingHier = function () {
            userService.setpreviousView('app.home');
            $state.go('ratingHier');
        }

        $scope.showDSRHier = function () {
            userService.setpreviousView('app.home');
            $state.go('dsrHier');
        }



        $scope.logOut = function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Processing'
            });
            window.localStorage.setItem('empCode', "");
            window.localStorage.setItem('empPassword', "");
            $state.go('login');
            $timeout(function () {
                $ionicLoading.hide();
            }, 2000);
        }




        $scope.openLinks = function (url) {
            window.open(url, '_system', 'location=no');
        }


        $scope.custSearch = function () {
            userService.setpreviousView('app.home');
            $state.go('custInfo');
        }


        function initiLiseValues() {
            $scope.lShow = false;
            $scope.pShow = false;
            $scope.languageUpdateResult = "";
            $scope.passrdUpdateResult = "";
            $scope.lShow = false;
            $scope.pShow = false;
            $scope.languageUpdateResult = "";
            $scope.passrdUpdateResult = "";
            $scope.logoDivHeight = $window.innerHeight - 381;
            $scope.user = userService.getUser();
            $scope.settings = {
                lang: $scope.language,
                OldPswd: "",
                NewPswrd: "",
                CPswrd: ""
            };
        }
        $scope.logOut = function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Processing'
            });
            window.localStorage.setItem('empCode', "");
            window.localStorage.setItem('empPassword', "");
            $state.go('login');
            $timeout(function () {
                $ionicLoading.hide();
            }, 1000);
        }

    })

    .controller('MainMenuController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform, userService, $ionicModal, $ionicPopup, $window) {
        $scope.logOut = function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Processing'
            });
            window.localStorage.setItem('empCode', "");
            window.localStorage.setItem('empPassword', "");
            $state.go('login');
            $timeout(function () {
                $ionicLoading.hide();
            }, 2000);
        }
        $scope.changeView = function (view) {
            userService.setpreviousView("app.home");
            $state.go(view);
        }

        $ionicModal.fromTemplateUrl('empProfile.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });
        $scope.showDProfile = function () {
            $scope.modal.show();
        }
        $scope.hideLubeTips = function () {
            $scope.modal.hide();
        }
        $scope.$on('$ionicView.enter', function () {

            $scope.employee = userService.getUser();

        });

    })



    .controller('RatingHierController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $timeout, $ionicPlatform, userService, $ionicHistory) {

        //Default two wheeler vechicles air pressures will be shown


        $scope.getNumber = function (num) {
            num = Math.floor(num);
            return num;
        }

        $scope.currentRating = {
            TOTAL_FEEDBACK: 0,
            AVGRATING: 0,
            PRODUCT_QUALITY: 0,
            QUANTITY_DELIVERED: 0,
            SERVICE: 0,
            FACILITIES: 0,
            CLEANINESS: 0,
            CLEANTOILET: 0
        };

        $scope.rating_AR1_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.currentRating.AVGRATING,
            minRating: 0,
            readOnly: true
        };

        $scope.rating_PQ_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.currentRating.PRODUCT_QUALITY,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_QD_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.currentRating.QUANTITY_DELIVERED,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_S_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.currentRating.SERVICE,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_CL_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.currentRating.CLEANINESS,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_F_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.currentRating.FACILITIES,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_CT_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.currentRating.CLEANTOILET,
            minRating: 0,
            readOnly: true
        };

        $scope.$on('$ionicView.enter', function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            $scope.drillDown = [];
            $scope.currentRating = {
                TOTAL_FEEDBACK: 0,
                AVGRATING: 0,
                PRODUCT_QUALITY: 0,
                QUANTITY_DELIVERED: 0,
                SERVICE: 0,
                FACILITIES: 0,
                CLEANINESS: 0,
                CLEANTOILET: 0
            };
            $scope.employee = userService.getUser();
            var serviceDetails = userService.getServiceDetails();
            var empHier = serviceDetails.empHier;
            if (empHier == "SG") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoRatingList";
                serviceDetails.paramKey = "sales_group";
                serviceDetails.paramName = $scope.employee.salesArea;
                serviceDetails.paramValue = $scope.employee.salesGroup;
                serviceDetails.arrayName = "RoRatingListOutput";
                serviceDetails.hierFieldId = "custcode";
                serviceDetails.hierFieldValue = "cust_name";
            } else if (empHier == "DO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSgRatingList";
                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "SgRatingListOutput";
                serviceDetails.hierFieldId = "salesarea";
                serviceDetails.hierFieldValue = "salesarea_name";
            } else if (empHier == "SO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSDoRatingList";
                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "DoRatingListOutput";
                serviceDetails.hierFieldId = "salesoff";
                serviceDetails.hierFieldValue = "salesoff_NAME";
            } else if (empHier == "HO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSoRatingList";
                serviceDetails.paramKey = "";
                serviceDetails.empHier = "HO";
                serviceDetails.paramName = "All India";
                serviceDetails.paramValue = "";
                serviceDetails.arrayName = "SoRatingListOutput";
                serviceDetails.hierFieldId = "salesorg";
                serviceDetails.hierFieldValue = "SALESORG_NAME";
            }
            loadRatings();
        });


        function addToDrillDown(sD) {
            var drillDownObj = {
                url: "",
                paramKey: "",
                empHier: "",
                paramName: "",
                paramValue: "",
                arrayName: "",
                hierFieldId: "",
                hierFieldValue: ""
            };
            drillDownObj.url = sD.url;
            drillDownObj.paramKey = sD.paramKey;
            drillDownObj.empHier = sD.empHier;
            drillDownObj.paramName = sD.paramName;
            drillDownObj.paramValue = sD.paramValue;
            drillDownObj.arrayName = sD.arrayName;
            drillDownObj.hierFieldId = sD.hierFieldId;
            drillDownObj.hierFieldValue = sD.hierFieldValue;
            $scope.drillDown.push(drillDownObj);
        }
        function loadRatings() {
            $scope.serviceDetails = userService.getServiceDetails();
            var serviceDetails = $scope.serviceDetails;
            addToDrillDown(serviceDetails);

            $http.get(serviceDetails.url + "?" + serviceDetails.paramKey + "=" + serviceDetails.paramValue)
                .success(function (data, status) {
                    if (data) {
                        $scope.ratings = data[serviceDetails.arrayName];

                        for (var ii = 0; ii < $scope.ratings.length; ii++) {

                            if (JSON.stringify($scope.ratings[ii].AVGRATING).indexOf("@nil") > -1) {
                                $scope.ratings[ii].AVGRATING = "0";
                            }
                            if (JSON.stringify($scope.ratings[ii].PRODUCT_QUALITY).indexOf("@nil") > -1) {
                                $scope.ratings[ii].PRODUCT_QUALITY = "0";
                            }
                            if (JSON.stringify($scope.ratings[ii].QUANTITY_DELIVERED).indexOf("@nil") > -1) {
                                $scope.ratings[ii].QUANTITY_DELIVERED = "0";
                            }
                            if (JSON.stringify($scope.ratings[ii].SERVICE).indexOf("@nil") > -1) {
                                $scope.ratings[ii].SERVICE = "0";
                            }
                            if (JSON.stringify($scope.ratings[ii].CLEANINESS).indexOf("@nil") > -1) {
                                $scope.ratings[ii].CLEANINESS = "0";
                            }
                            if (JSON.stringify($scope.ratings[ii].FACILITIES).indexOf("@nil") > -1) {
                                $scope.ratings[ii].FACILITIES = "0";
                            }
                            if (JSON.stringify($scope.ratings[ii].CLEANTOILET).indexOf("@nil") > -1) {
                                $scope.ratings[ii].CLEANTOILET = "0";
                            }

                        }
                    }

                    $ionicLoading.hide();
                }).error(onError);

        }


        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }

        $scope.showSelectedHier = function (dObj) {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $scope.ratings = [];
            var tempDrillDown = [];
            for (var ii = 0; ii < $scope.drillDown.length; ii++) {
                if (dObj.empHier == $scope.drillDown[ii].empHier) {
                    break;
                }
                tempDrillDown.push($scope.drillDown[ii]);
            }
            $scope.drillDown = [];
            $scope.drillDown = tempDrillDown;
            userService.setServiceDetails(dObj);
            loadRatings();
        }

        $scope.showNextHier = function (rating) {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $scope.ratings = [];
            //userService.setServiceDetails(drillDownObj);
            var serviceDetails = userService.getServiceDetails();
            var empHier = serviceDetails.empHier;
            if (empHier == "HO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSDoRatingList";
                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.paramName = rating[serviceDetails.hierFieldValue];
                serviceDetails.paramValue = rating[serviceDetails.hierFieldId];
                serviceDetails.arrayName = "DoRatingListOutput";
                serviceDetails.hierFieldId = "salesoff";
                serviceDetails.hierFieldValue = "salesoff_NAME";
            } else if (empHier == "SO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSgRatingList";
                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.paramName = rating[serviceDetails.hierFieldValue];
                serviceDetails.paramValue = rating[serviceDetails.hierFieldId];
                serviceDetails.arrayName = "SgRatingListOutput";
                serviceDetails.hierFieldId = "salesarea";
                serviceDetails.hierFieldValue = "salesarea_name";
            } else if (empHier == "DO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoRatingList";
                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.paramName = rating[serviceDetails.hierFieldValue];
                serviceDetails.paramValue = rating[serviceDetails.hierFieldId];
                serviceDetails.arrayName = "RoRatingListOutput";
                serviceDetails.hierFieldId = "custcode";
                serviceDetails.hierFieldValue = "cust_name";
            }
            userService.setServiceDetails(serviceDetails);
            loadRatings();
        }

        $ionicModal.fromTemplateUrl('ratingSummary.html', function (modal) {
            $scope.ratingModal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });


        $scope.hideRatingSummary = function () {
            $scope.ratingModal.hide();
        }

        $scope.showRatingSummaryPop = function (rating) {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            $scope.currentRating = rating;
            console.log(JSON.stringify(rating));
            /*
             
             $scope.rating_AR1_Object.setRating(Math.floor($scope.currentRating.AVGRATING));
             
             */
            $scope.rating_AR1_Object.setRating(Math.floor($scope.currentRating.AVGRATING));
            $scope.rating_PQ_Object.setRating(Math.floor($scope.currentRating.PRODUCT_QUALITY));
            $scope.rating_QD_Object.setRating(Math.floor($scope.currentRating.QUANTITY_DELIVERED));
            $scope.rating_S_Object.setRating(Math.floor($scope.currentRating.SERVICE));
            $scope.rating_CL_Object.setRating(Math.floor($scope.currentRating.CLEANINESS));
            $scope.rating_F_Object.setRating(Math.floor($scope.currentRating.FACILITIES));
            $scope.rating_CT_Object.setRating(Math.floor($scope.currentRating.CLEANTOILET));

            $scope.ratingModal.show();
            $ionicLoading.hide();
        }

        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('DSRHierController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $scope.getNumber = function (num) {
            num = Math.floor(num);
            return num;
        }

        $scope.currentDSR = {
            LY_MS: 0,
            MS_TARGET: 0,
            PRORATA_LY_MS: 0,
            PRORATA_TARGET_MS: 0,
            CURRENT_MS: 0,
            CURRENT_MS_PERC: 0,
            TARGET_MS_PERC: 0,
            BALANCE_MS: 0,
            LY_HSD: 0,
            HSD_TARGET: 0,
            PRORATA_LY_HSD: 0,
            PRORATA_TARGET_HSD: 0,
            CURRENT_HSD: 0,
            CURRENT_HSD_PERC: 0,
            TARGET_HSD_PERC: 0,
            BALANCE_HSD: 0
        };


        $scope.$on('$ionicView.enter', function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            $scope.drillDown = [];
            $scope.currentDSR = {
                LY_MS: 0,
                MS_TARGET: 0,
                PRORATA_LY_MS: 0,
                PRORATA_TARGET_MS: 0,
                CURRENT_MS: 0,
                CURRENT_MS_PERC: 0,
                TARGET_MS_PERC: 0,
                BALANCE_MS: 0,
                LY_HSD: 0,
                HSD_TARGET: 0,
                PRORATA_LY_HSD: 0,
                PRORATA_TARGET_HSD: 0,
                CURRENT_HSD: 0,
                CURRENT_HSD_PERC: 0,
                TARGET_HSD_PERC: 0,
                BALANCE_HSD: 0
            };

            $scope.tabNumber = 1;
            $scope.employee = userService.getUser();
            var serviceDetails = userService.getServiceDetails();
            var empHier = serviceDetails.empHier;
            if (empHier == "SG") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoDsrList";
                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.paramName = $scope.employee.salesArea;
                serviceDetails.paramValue = $scope.employee.salesGroup;
                serviceDetails.arrayName = "dbDSRroListOutput";
                serviceDetails.hierFieldId = "RO_CODE";
                serviceDetails.hierFieldValue = "DEALER";
            } else if (empHier == "DO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSgDsrList";
                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "dbDSRsgListOutput";
                serviceDetails.hierFieldId = "salesarea";
                serviceDetails.hierFieldValue = "salesarea_name";
            } else if (empHier == "SO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSDoDsrList";
                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "dbDSRdoListOutput";
                serviceDetails.hierFieldId = "salesoff";
                serviceDetails.hierFieldValue = "salesoff_name";
            } else if (empHier == "HO" || empHier == "IS") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSoDsrList";
                serviceDetails.paramKey = "";
                serviceDetails.empHier = "HO";
                serviceDetails.paramName = "All India";
                serviceDetails.paramValue = "";
                serviceDetails.arrayName = "dbDSRsoListOutput";
                serviceDetails.hierFieldId = "SALESORG";
                serviceDetails.hierFieldValue = "SALESORG_NAME";
            }
            console.log(JSON.stringify(serviceDetails));
            userService.setServiceDetails(serviceDetails);
            loadDSR();
        });


        function addToDrillDown(sD) {
            var drillDownObj = {
                url: "",
                paramKey: "",
                empHier: "",
                paramName: "",
                paramValue: "",
                arrayName: "",
                hierFieldId: "",
                hierFieldValue: ""
            };
            drillDownObj.url = sD.url;
            drillDownObj.paramKey = sD.paramKey;
            drillDownObj.empHier = sD.empHier;
            drillDownObj.paramName = sD.paramName;
            drillDownObj.paramValue = sD.paramValue;
            drillDownObj.arrayName = sD.arrayName;
            drillDownObj.hierFieldId = sD.hierFieldId;
            drillDownObj.hierFieldValue = sD.hierFieldValue;
            $scope.drillDown.push(drillDownObj);
        }


        function loadDSR() {
            $scope.serviceDetails = userService.getServiceDetails();
            var serviceDetails = $scope.serviceDetails;
            addToDrillDown(serviceDetails);

            $http.get(serviceDetails.url + "?" + serviceDetails.paramKey + "=" + serviceDetails.paramValue)
                .success(function (data, status) {
                    if (data) {
                        $scope.dsr = data[serviceDetails.arrayName];

                        for (var ii = 0; ii < $scope.dsr.length; ii++) {
                            if (data[serviceDetails.arrayName][ii].PRORATA_LY_MS > 0) {
                                $scope.dsr[ii].CURRENT_MS_PERC = (((data[serviceDetails.arrayName][ii].CURRENT_MS - data[serviceDetails.arrayName][ii].PRORATA_LY_MS) / data[serviceDetails.arrayName][ii].PRORATA_LY_MS) * 100).toFixed(2);
                            } else {
                                $scope.dsr[ii].CURRENT_MS_PERC = 0;
                            }
                            if (data[serviceDetails.arrayName][ii].PRORATA_TARGET_MS > 0) {
                                $scope.dsr[ii].TARGET_MS_PERC = (((data[serviceDetails.arrayName][ii].CURRENT_MS - data[serviceDetails.arrayName][ii].PRORATA_TARGET_MS) / data[serviceDetails.arrayName][ii].PRORATA_TARGET_MS) * 100).toFixed(2);
                            } else {
                                $scope.dsr[ii].TARGET_MS_PERC = 0;
                            }

                            if (data[serviceDetails.arrayName][ii].PRORATA_LY_HSD > 0) {
                                $scope.dsr[ii].CURRENT_HSD_PERC = (((data[serviceDetails.arrayName][ii].CURRENT_HSD - data[serviceDetails.arrayName][ii].PRORATA_LY_HSD) / data[serviceDetails.arrayName][ii].PRORATA_LY_HSD) * 100).toFixed(2);
                            } else {
                                $scope.dsr[ii].CURRENT_HSD_PERC = 0;
                            }

                            if (data[serviceDetails.arrayName][ii].PRORATA_TARGET_HSD > 0) {
                                $scope.dsr[ii].TARGET_HSD_PERC = (((data[serviceDetails.arrayName][ii].CURRENT_HSD - data[serviceDetails.arrayName][ii].PRORATA_TARGET_HSD) / data[serviceDetails.arrayName][ii].PRORATA_TARGET_HSD) * 100).toFixed(2);
                            } else {
                                $scope.dsr[ii].TARGET_HSD_PERC = 0;
                            }
                            $scope.dsr[ii].CURRENT_MS = $scope.dsr[ii].CURRENT_MS.toFixed(0);
                            $scope.dsr[ii].CURRENT_HSD = $scope.dsr[ii].CURRENT_HSD.toFixed(0);
                        }


                    }

                    $ionicLoading.hide();
                }).error(onError);


        }



        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }

        $scope.showSelectedHier = function (dObj) {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $scope.dsr = [];
            var tempDrillDown = [];
            for (var ii = 0; ii < $scope.drillDown.length; ii++) {
                if (dObj.empHier == $scope.drillDown[ii].empHier) {
                    break;
                }
                tempDrillDown.push($scope.drillDown[ii]);
            }
            $scope.drillDown = [];
            $scope.drillDown = tempDrillDown;
            userService.setServiceDetails(dObj);
            loadDSR();
        }

        $scope.showNextHier = function (dsr) {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $scope.ratings = [];
            //userService.setServiceDetails(drillDownObj);
            var serviceDetails = userService.getServiceDetails();
            var empHier = serviceDetails.empHier;


            if (empHier == "HO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSDoDsrList";
                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.paramName = dsr[serviceDetails.hierFieldValue];
                serviceDetails.paramValue = dsr[serviceDetails.hierFieldId];
                serviceDetails.arrayName = "dbDSRdoListOutput";
                serviceDetails.hierFieldId = "salesoff";
                serviceDetails.hierFieldValue = "salesoff_name";
            } else if (empHier == "SO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSgDsrList";
                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.paramName = dsr[serviceDetails.hierFieldValue];
                serviceDetails.paramValue = dsr[serviceDetails.hierFieldId];
                serviceDetails.arrayName = "dbDSRsgListOutput";
                serviceDetails.hierFieldId = "salesarea";
                serviceDetails.hierFieldValue = "salesarea_name";
            } else if (empHier == "DO") {
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoDsrList";
                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.paramName = dsr[serviceDetails.hierFieldValue];
                serviceDetails.paramValue = dsr[serviceDetails.hierFieldId];
                serviceDetails.arrayName = "dbDSRroListOutput";
                serviceDetails.hierFieldId = "RO_CODE";
                serviceDetails.hierFieldValue = "DEALER";
            }
            userService.setServiceDetails(serviceDetails);
            loadDSR();
        }

        $ionicModal.fromTemplateUrl('dsrSummary.html', function (modal) {
            $scope.dsrModal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });


        $scope.hideDSR = function () {
            $scope.dsrModal.hide();
        }

        $scope.showDSRSummaryPop = function (dsr) {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            $scope.currentDSR = dsr;
            console.log(JSON.stringify(dsr));

            $scope.dsrModal.show();
            $ionicLoading.hide();
        }

        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('CustInfoController', function ($scope, $state, $http, $ionicPopup, $ionicLoading, $ionicModal, $timeout, $ionicPlatform, userService, $ionicHistory) {



        //Default two wheeler vechicles air pressures will be shown
        $scope.searchString = {
            val: ""
        };

        $scope.$on('$ionicView.enter', function () {

        });

        $scope.searchBasedOnVal = function () {
            if ($scope.searchString.val && $scope.searchString.val.length >= 3) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });
                $scope.roResults = [];
                $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoSearch?nodename=HO&nodevalue=&input_text=" + $scope.searchString.val)
                    .success(function (data, status) {
                        if (data && data.OUT_RO && data.OUT_RO.OUT_RO_Row && data.OUT_RO.OUT_RO_Row.length > 0) {
                            $scope.roResults = data.OUT_RO.OUT_RO_Row;
                        } else {
                            $scope.roResults = [];
                        }
                        $ionicLoading.hide();
                    }).error(onError);
            }
        }



        $scope.searchForceFully = function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoSearch?nodename=HO&nodevalue=&input_text=" + $scope.searchString.val)
                .success(function (data, status) {
                    if (data && data.OUT_RO && data.OUT_RO.OUT_RO_Row && data.OUT_RO.OUT_RO_Row.length > 0) {
                        $scope.roResults = data.OUT_RO.OUT_RO_Row;
                    } else {
                        alert("No Results Found");
                    }
                    $ionicLoading.hide();
                }).error(onError);
        }

        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
        $scope.goToXsparshView = function (ro) {
            userService.setRo(ro);
            userService.setIsXsparshView(true);
            $state.go('xsparsh.xSparsh_home');

        }
        function onError() {
            alert('Error Occured');
            $ionicLoading.hide();
        }
    })

    .controller('SGOrderController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {


        $scope.dealer = userService.getUser();


        $scope.$on('$ionicView.enter', function () {

            var date = new Date();
            $scope.IndentFromDate = {
                val: date
            };
            $scope.IndentToDate = {
                val: date
            };

            $scope.customers = [];
            $scope.selection = {
                SO: "",
                DO: "",
                SG: ""
            };
            $scope.customer = {};

            $scope.employee = userService.getUser();
            var serviceDetails = {};
            var empRole = $scope.employee.empRole;
            $scope.showOrderStatus = false;
            $scope.showOrderStatusHier = false;

            if (empRole == "FO-RS") {
                //$scope.showOrderStatus = true;
                //serviceDetails.paramName = $scope.employee.salesArea;
                //serviceDetails.paramValue = $scope.employee.salesGroup;
            } else {
                //$scope.showOrderStatus = false;
                $ionicLoading.show({
                });
                serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSSalesArea";
                serviceDetails.paramKey = "1";
                serviceDetails.empHier = "1";
                serviceDetails.paramName = $scope.employee.locName;
                serviceDetails.paramValue = $scope.employee.locCode;
                serviceDetails.arrayName = "MstSalesarea";

                $http.get(serviceDetails.url + "?" + serviceDetails.paramKey + "=" + serviceDetails.paramValue)
                    .success(function (data, status) {
                        if (data) {
                            $scope.salesGroups = data[serviceDetails.arrayName];
                            $ionicLoading.hide();
                        } else {
                            $scope.salesGroups = [];
                            $ionicLoading.hide();
                        }
                    }).error(onError);
            }


            if (empRole == "DO-RS") {
                $scope.selection.DO = $scope.employee.locCode;
                //$scope.selection.DO = "1101";
            } else if (empRole == "SO-RS") {
                $scope.selection.SO = $scope.employee.locCode;
                //$scope.selection.SO = "1100";
            }
            $scope.tabNumber = 1;

            $scope.ordersDispatched = [];
            $scope.ordersLoading = [];
            $scope.ordersPending = [];
            $scope.orders = [];
        });


        $ionicModal.fromTemplateUrl('custOrder.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });


        $scope.showCustOrder = function () {
            $scope.modal.show();
        }

        $scope.hideCustOrder = function () {
            $scope.modal.hide();
            $scope.hideSingleOrder();
        }

        $scope.showTab = function (val) {
            if (val == 1) {
                $scope.orders = $scope.ordersPending;
            } else if (val == 2) {
                $scope.orders = $scope.ordersLoading;
            } else {
                $scope.orders = $scope.ordersDispatched;
            }
            $scope.tabNumber = val;

        }

        function onError(data) {
            $scope.error = true;
            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'Some Internal Error Occurred'
            });
            $ionicLoading.hide();
        }

        $scope.getVolumeSum = function (items) {
            return items
                .map(function (x) {
                    return x.Qunatity;
                })
                .reduce(function (a, b) {
                    return parseFloat(a) + parseFloat(b);
                });
        };

        $scope.getOrderStatus = function () {
            $scope.ordersDispatched = [];
            $scope.ordersLoading = [];
            $scope.ordersPending = [];
            $scope.orders = [];
            if (validateValues()) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });


                var fromDate = new Date($scope.IndentFromDate.val);
                var toDate = new Date($scope.IndentToDate.val);

                fromDate = fromDate.getFullYear() + "-" + (fromDate.getMonth() + 1) + "-" + fromDate.getDate();
                toDate = toDate.getFullYear() + "-" + (toDate.getMonth() + 1) + "-" + toDate.getDate();
                var sg = "";
                if ($scope.selection.SG == "") {
                    sg = $scope.employee.salesGroup;
                } else {
                    sg = $scope.selection.SG
                }
                var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_MP_SERVICES_SRV/ZMPORDERFLOWSet?$filter=Vkgrp%20eq%20%27" + sg + "%27%20and%20DateFrom%20eq%20datetime%27" + fromDate + "T00:00:00%27%20and%20DateTo%20eq%20datetime%27" + toDate + "T00:00:00%27&$format=json"

                $http.get(url)
                    .success(function (data, status) {
                        if (data) {

                            $scope.orderStatus = data.d.results;
                            for (var i = 0; i < $scope.orderStatus.length; i++) {
                                if (($scope.orderStatus[i].Comment).toLowerCase() == 'load dispatched') {
                                    $scope.ordersDispatched.push($scope.orderStatus[i]);
                                } else if (($scope.orderStatus[i].Comment).toLowerCase() == 'delivery created' || ($scope.orderStatus[i].Comment).toLowerCase() == 'shipment created') {
                                    $scope.ordersLoading.push($scope.orderStatus[i]);
                                } else {
                                    $scope.ordersPending.push($scope.orderStatus[i]);
                                }
                            }
                            $scope.tabNumber = 1;
                            $scope.orders = $scope.ordersPending;
                        } else {
                            $scope.orderStatus = [];
                        }
                        $scope.showOrderStatusHier = true;
                        generateOrderSummary();

                    }).error(onError);
            }

        }


        function validateValues() {
            var fromDate = new Date($scope.IndentFromDate.val);
            var toDate = new Date($scope.IndentToDate.val);

            var todayDate = new Date();

            fromDate = new Date(fromDate.getFullYear(), fromDate.getMonth(), fromDate.getDate()); //Year, Month, Date
            toDate = new Date(toDate.getFullYear(), toDate.getMonth(), toDate.getDate()); //Year, Month, Date
            todayDate = new Date(todayDate.getFullYear(), todayDate.getMonth(), todayDate.getDate());



            if ($scope.employee.empRole == 'HO-RS' || $scope.employee.empRole == 'IS') {
                if ($scope.selection.SO == "") {
                    alert("Select State Office");
                    return false;
                }
            }

            if ($scope.employee.empRole == 'HO-RS' || $scope.employee.empRole == 'IS' || $scope.employee.empRole == 'SO-RS') {
                if ($scope.selection.DO == "") {
                    alert("Select Divisional Office");
                    return false;
                }
            }

            if ($scope.employee.empRole == 'HO-RS' || $scope.employee.empRole == 'IS' || $scope.employee.empRole == 'SO-RS' || $scope.employee.empRole == 'DO-RS') {
                if ($scope.selection.SG == "") {
                    alert("Select Sales Group");
                    return false;
                }
            }


            if (fromDate > toDate) {
                alert("From date cannot more than To date");
                return false;
            } else if (fromDate > todayDate) {
                alert("From date cannot more than Today date");
                return false;
            } else if (toDate > todayDate) {
                alert("To date cannot more than Today date");
                return false;
            } else {
                var a = (toDate - fromDate) / (1000 * 3600 * 24);
                if (a > 7) {
                    alert("Difference between two dates cannot be more than seven days.");
                    return false;
                }
            }

            return true;
        }

        $scope.showOrderSummary = function (txt) {
            for (var ii = 0; ii < $scope.orderStatus.length; ii++) {
                var tt = $scope.orderStatus[ii].Ordrno.toString() + $scope.orderStatus[ii].Matcode.toString();
                if (tt == txt) {
                    $scope.orderStatus[ii].show = true;
                } else {
                    $scope.orderStatus[ii].show = false;
                }
            }
        }

        function generateOrderSummary() {

            for (var ii = 0; ii < $scope.orderStatus.length; ii++) {
                $scope.orderStatus[ii].show = false;
                if ($scope.orderStatus[ii].Ordrdt) {
                    var tt = $scope.orderStatus[ii].Ordrdt.substring(6, $scope.orderStatus[ii].Ordrdt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].Ordrdt = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].DelDate) {
                    var tt = $scope.orderStatus[ii].DelDate.substring(6, $scope.orderStatus[ii].DelDate.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].DelDate = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].ShpmntDt) {
                    var tt = $scope.orderStatus[ii].ShpmntDt.substring(6, $scope.orderStatus[ii].ShpmntDt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].ShpmntDt = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].LoadDate) {
                    var tt = $scope.orderStatus[ii].LoadDate.substring(6, $scope.orderStatus[ii].LoadDate.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].LoadDate = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].Reqdeldt) {
                    var tt = $scope.orderStatus[ii].Reqdeldt.substring(6, $scope.orderStatus[ii].Reqdeldt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].Reqdeldt = dd.toString().substring(0, 15);
                }

                $scope.orderStatus[ii].ShpmntTime = $scope.orderStatus[ii].ShpmntTime.substring(2, 4) + ":" + $scope.orderStatus[ii].ShpmntTime.substring(5, 7) + ":" + $scope.orderStatus[ii].ShpmntTime.substring(8, 10);
                $scope.orderStatus[ii].DelTime = $scope.orderStatus[ii].DelTime.substring(2, 4) + ":" + $scope.orderStatus[ii].DelTime.substring(5, 7) + ":" + $scope.orderStatus[ii].DelTime.substring(8, 10);
                $scope.orderStatus[ii].LoadTime = $scope.orderStatus[ii].LoadTime.substring(2, 4) + ":" + $scope.orderStatus[ii].LoadTime.substring(5, 7) + ":" + $scope.orderStatus[ii].LoadTime.substring(8, 10);
                $scope.orderStatus[ii].Erzet = $scope.orderStatus[ii].Erzet.substring(2, 4) + ":" + $scope.orderStatus[ii].Erzet.substring(5, 7) + ":" + $scope.orderStatus[ii].Erzet.substring(8, 10);

            }




            var prodOrderStatus = _.groupBy($scope.orderStatus, "Matcode");

            $scope.prodOrderSummary = [];
            for (var pos in prodOrderStatus) {
                var tempArr = prodOrderStatus[pos];
                var tempObj = {
                    product: "",
                    productName: "",
                    quantityDispatched: 0,
                    quantityLoading: 0,
                    quantityPending: 0
                }
                tempObj.product = prodOrderStatus[pos][0].Matcode;
                tempObj.productName = prodOrderStatus[pos][0].Matdesc;

                for (var jj = 0; jj < tempArr.length; jj++) {
                    if (tempArr[jj].Comment == "Load Dispatched") {
                        tempObj.quantityDispatched += parseFloat(tempArr[jj].Qunatity);
                    } else if (tempArr[jj].Comment == "Delivery Created" || tempArr[jj].Comment == "Shipment Created") {
                        tempObj.quantityLoading += parseFloat(tempArr[jj].Qunatity);
                    } else {
                        tempObj.quantityPending += parseFloat(tempArr[jj].Qunatity);
                    }
                }
                tempObj.quantityDispatched = (tempObj.quantityDispatched).toFixed(2);
                tempObj.quantityLoading = (tempObj.quantityLoading).toFixed(2);
                tempObj.quantityPending = (tempObj.quantityPending).toFixed(2)
                $scope.prodOrderSummary.push(tempObj);
            }
            $ionicLoading.hide();
        }


        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('ResetPINController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });

        $scope.dealer = userService.getUser();


        $scope.$on('$ionicView.enter', function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            $scope.employee = userService.getUser();
            var serviceDetails = {};
            $scope.customer = {
                cust_id: ""
            };

            if ($scope.employee.empRole != "FO-RS") {
                $state.go("app.home");
            }
            $ionicLoading.hide();
            /*else {
             
             serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSShowSARO";
             serviceDetails.paramKey = "salesarea";
             serviceDetails.empHier = "SG";
             serviceDetails.paramName = $scope.employee.salesArea;
             serviceDetails.paramValue = $scope.employee.salesGroup;
             serviceDetails.arrayName = "SACustDBOutput";
             $http.get(serviceDetails.url + "?" + serviceDetails.paramKey + "=" + serviceDetails.paramValue)
             .success(function (data, status) {
             if (data) {
             $scope.customers = data[serviceDetails.arrayName];
             $ionicLoading.hide();
             } else {
             $scope.customers = [];
             $ionicLoading.hide();
             }
             }).error(onError);
             
             
             }*/

        });

        function onError(data) {
            $scope.error = true;
            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'Some Internal Error Occurred'
            });
            $ionicLoading.hide();
        }

        $scope.resetIPIN = function () {
            if ($scope.customer.cust_id.length >= 6) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });
                $http.get("https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_IPIN_SRV/ZMAORDEROTPSet(Customer='" + $scope.customer.cust_id + "',OldOtp='',Otp='')?$format=json")
                    .success(function (data, status) {
                        $ionicLoading.hide();
                        var alertPopup = $ionicPopup.alert({
                            title: ' Success',
                            template: 'IPIN reset to 0000'
                        });
                        $scope.customer.cust_id = "";
                    }).error(onError);
            } else {
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: 'Enter valid customer no.'
                });
            }
        }

        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('SalesAnalyticsController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {
        $scope.months = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", "Total"];
        $scope.selectedProduct = "MS";
        $scope.error = false;
        $scope.$on('$ionicView.enter', function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $scope.employee = userService.getUser();
            $scope.tabNumber = 1;
            loadHistorySales();
        });
        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }

        function loadHistorySales() {
            $scope.error = false;
            var serviceDetails = {};
            var empRole = $scope.employee.empRole;
            serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSHistSales";
            $scope.area = "";
            if (empRole == "FO-RS") {

                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.nodename = "FO";
                serviceDetails.nodevalue = $scope.employee.salesGroup;
                serviceDetails.paramName = $scope.employee.salesArea;

            } else if (empRole == "DO-RS") {

                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.nodename = $scope.employee.locCode;
                serviceDetails.nodevalue = "1101";

                serviceDetails.paramName = $scope.employee.locName;

            } else if (empRole == "SO-RS") {

                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.nodename = "SO";
                serviceDetails.nodevalue = $scope.employee.locCode;
                serviceDetails.paramName = $scope.employee.locName;


            } else if (empRole == "HO-RS" || empRole == "IS") {

                serviceDetails.paramKey = "";
                serviceDetails.empHier = "HO";
                serviceDetails.nodename = "HO";
                serviceDetails.nodevalue = "";
                serviceDetails.paramName = "All India";
            }
            $scope.serviceDetails = serviceDetails;
            var urlS = serviceDetails.url + "?nodename=" + serviceDetails.nodename + "&nodevalue=" + serviceDetails.nodevalue;
            $http.get(urlS)
                .success(function (data, status) {
                    if (data) {
                        $scope.sales = data.SALES_OUTPUT.SALES_OUTPUT_Row;


                        for (var ii = 0; ii < $scope.sales.length; ii++) {
                            $scope.sales[ii].YYYYMM = parseInt($scope.sales[ii].YYYYMM.toString().substring(4, 6)) - 1;
                            if (JSON.stringify($scope.sales[ii].MS_TARGET).indexOf("@nil") > -1) {
                                $scope.sales[ii].MS_TARGET = 0;
                            }
                            if (JSON.stringify($scope.sales[ii].HSD_TARGET).indexOf("@nil") > -1) {
                                $scope.sales[ii].HSD_TARGET = 0;
                            }

                        }


                        $scope.totalSales = {
                            "LY_MS_SALES": 0,
                            "MS_SALES": 0,
                            "MS_TARGET": 0,
                            "LY_HSD_SALES": 0,
                            "HSD_SALES": 0,
                            "HSD_TARGET": 0
                        }

                        for (var ii = 0; ii < $scope.sales.length; ii++) {
                            $scope.totalSales.LY_MS_SALES += $scope.sales[ii].LY_MS_SALES;
                            $scope.totalSales.MS_SALES += $scope.sales[ii].MS_SALES;
                            $scope.totalSales.MS_TARGET += $scope.sales[ii].MS_TARGET;
                            $scope.totalSales.LY_HSD_SALES += $scope.sales[ii].LY_HSD_SALES;
                            $scope.totalSales.HSD_SALES += $scope.sales[ii].HSD_SALES;
                            $scope.totalSales.HSD_TARGET += $scope.sales[ii].HSD_TARGET;
                        }
                        $scope.totalSales.LY_MS_SALES = $scope.totalSales.LY_MS_SALES.toFixed(2);
                        $scope.totalSales.MS_SALES = $scope.totalSales.MS_SALES.toFixed(2);
                        $scope.totalSales.MS_TARGET = $scope.totalSales.MS_TARGET.toFixed(2);
                        $scope.totalSales.LY_HSD_SALES = $scope.totalSales.LY_HSD_SALES.toFixed(2);
                        $scope.totalSales.HSD_SALES = $scope.totalSales.HSD_SALES.toFixed(2);
                        $scope.totalSales.HSD_TARGET = $scope.totalSales.HSD_TARGET.toFixed(2);
                        //$scope.sales.push(tempTotalSales);

                    } else {
                        $scope.sales = {};
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                $scope.error = true;
                $ionicLoading.hide();
            }
        }
        $ionicModal.fromTemplateUrl('SalesSummary.html', function (modal) {
            $scope.salesModal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $scope.showSalesSummaryPop = function () {
            $scope.salesModal.show();
        }
        $scope.hideSalesSummaryPop = function () {
            $scope.salesModal.hide();
        }

    })

    .controller('CustomerCentricController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        var dateobj = new Date();
        var month = dateobj.getMonth() + 1;
        var year = dateobj.getFullYear();

        if (month < 10) {
            $scope.data = {
                val: year.toString() + "-0" + month.toString()
            }
        } else {
            $scope.data = {
                val: year.toString() + "-" + month.toString()
            }
        }
        $scope.$on('$ionicView.enter', function () {

            $scope.employee = userService.getUser();
            $scope.tabNumber = 1;
            //loadCustomerCentricData();
        });
        $scope.loadCustomerCentricData = function () {
            var dy = $scope.data.val.split("-");
            var datVal = dy[0] + "" + dy[1];

            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            var serviceDetails = {};
            var empRole = $scope.employee.empRole;
            serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSCustCentric";
            if (empRole == "FO-RS") {

                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.nodename = "FO";
                serviceDetails.nodevalue = $scope.employee.salesGroup;
                serviceDetails.paramName = $scope.employee.salesArea;

            } else if (empRole == "DO-RS") {

                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.nodename = $scope.employee.locCode;
                serviceDetails.nodevalue = "1101";

                serviceDetails.paramName = $scope.employee.locName;

            } else if (empRole == "SO-RS") {

                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.nodename = "SO";
                serviceDetails.nodevalue = $scope.employee.locCode;
                serviceDetails.paramName = $scope.employee.locName;


            } else if (empRole == "HO-RS" || empRole == "IS") {

                serviceDetails.paramKey = "";
                serviceDetails.empHier = "HO";
                serviceDetails.nodename = "HO";
                serviceDetails.nodevalue = "";
                serviceDetails.paramName = "All India";
            }

            $scope.serviceDetails = serviceDetails;
            var urlS = serviceDetails.url + "?nodename=" + serviceDetails.nodename + "&nodevalue=" + serviceDetails.nodevalue + "&ccdate=" + datVal;
            $http.get(urlS)
                .success(function (data, status) {
                    if (data) {
                        $scope.ccData = data.OUTPUT_REF.OUTPUT_REF_Row[0];
                        var aa = "";

                    } else {

                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                $scope.error = true;
                $ionicLoading.hide();
            }
        }


        $scope.employee = userService.getUser();
        $scope.dates = [];





        for (var i = 0; i < 12; i++) {
            if (month == 0) {
                month = 12;
                year = year - 1;
            }
            if (month < 10) {
                $scope.dates[i] = year.toString() + "-0" + month.toString();
            } else {
                $scope.dates[i] = year.toString() + "-" + month.toString()
            }

            month = month - 1;
        }
        $scope.loadCustomerCentricData();


        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('LocationStockController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $scope.stockDate = {
            val: ""
        };
        var dateString = "";

        function LoadStockData() {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            var urlS = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSLocStock" + "?stock_date=" + dateString;
            $http.get(urlS)
                .success(function (data, status) {
                    if (data && data.OUTPUT_REF && data.OUTPUT_REF.OUTPUT_REF_Row) {
                        $scope.lcnStcData = data.OUTPUT_REF.OUTPUT_REF_Row;
                        for (var i = 0; i < $scope.lcnStcData.length; i++) {

                            if ($scope.lcnStcData[i].STATUS.toLowerCase().indexOf("adequate") >= 0) {
                                $scope.lcnStcData[i].color = "green";
                            } else {
                                $scope.lcnStcData[i].color = "red";
                            }
                        }
                        var aa = "";

                    } else {
                        alert("No Data Found");
                        $scope.lcnStcData = [];
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                $scope.error = true;
                $ionicLoading.hide();
            }
        }

        $scope.getStock = function () {
            var dd = new Date($scope.stockDate.val);


            var month = (dd.getMonth() + 1).toString();

            if (month.length === 1) {
                month = "0" + month;
            }

            var day = dd.getDate().toString();
            if (day.length === 1) {
                day = "0" + day;
            }

            dateString = day + "-" + month + "-" + dd.getFullYear();
            LoadStockData();

        }


        $scope.lcStockFilter = function (val) {

            if ($scope.lcStockSearchString && $scope.lcStockSearchString.length > 0) {
                if (val.LOC_NAME.toLowerCase().indexOf($scope.lcStockSearchString.toLowerCase()) < 0) {
                    return false;
                }

                return true;
            } else {
                return true;
            }
        }

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('MrktIntlgenceVersionController', function ($scope, $state, $rootScope, $ionicPlatform, $ionicLoading, $http, $timeout, $ionicModal, userService, $ionicHistory) {

        $scope.selectedProduct = "SELECT";
        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });

        var dd = new Date();
        var month = (dd.getMonth() + 1).toString();

        if (month.length === 1) {
            month = "0" + month;
        }
        var dtString = dd.getFullYear() + "" + month;
        var urlS = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSMarketIntel?midate=" + dtString;
        $http.get(urlS)
            .success(function (data, status) {
                if (data) {
                    if (data.PRICING.PRICING_Row)
                        $scope.mtknInteligencePricing = data.PRICING.PRICING_Row;
                    if (data.LOYALTY && data.LOYALTY.LOYALTY_Row)
                        $scope.mtknInteligenceLoyalty = data.LOYALTY.LOYALTY_Row;
                    if (data.SALES_PROMO && data.SALES_PROMO.SALES_PROMO_Row)
                        $scope.mtknInteligenceSalespromo = data.SALES_PROMO.SALES_PROMO_Row;

                } else {

                }
                $ionicLoading.hide();
            }).error(onError);
        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }
        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
        $scope.change = function () {
            alert($scope.Type);
        }

    })

    .controller('RoCriticalityVersionController', function ($scope, $state, $rootScope, $ionicPlatform, $ionicLoading, $http, $timeout, $ionicModal, userService, $ionicHistory) {

        $scope.$on('$ionicView.enter', function () {
            loadReport();
        });

        function loadReport() {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            $scope.dealerCode = (userService.getUser()).rocode;
            $scope.critMsColor = "blue";
            $scope.critHsdColor = "blue";

            var urlS = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoStockCR?ro_code=" + $scope.dealerCode;
            $http.get(urlS)
                .success(function (data, status) {
                    if (data && data.STK_REPORT && data.STK_REPORT.STK_REPORT_Row) {
                        $scope.criticalityReport = data.STK_REPORT.STK_REPORT_Row[0];
                        if ($scope.criticalityReport.STK_POSITION_MS.toString().toLowerCase() == "critical") {
                            $scope.critMsColor = "red";
                        } else {
                            $scope.critMsColor = "blue";
                        }
                        if ($scope.criticalityReport.STK_POSITION_HSD.toString().toLowerCase() == "critical") {
                            $scope.critHsdColor = "red";
                        } else {
                            $scope.critHsdColor = "blue";
                        }
                    } else {
                        alert("No Data Found");
                        $ionicLoading.hide();
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                $scope.error = true;
                $ionicLoading.hide();
            }
        }

        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('xSparshMainController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform,
        userService, $ionicModal, $ionicPopup, $cordovaInAppBrowser, $cordovaDevice, $cordovaAppAvailability, $window) {

        $scope.language = "English";
        $scope.lShow = false;
        $scope.pShow = false;
        $scope.languageUpdateResult = "";
        $scope.passrdUpdateResult = "";
        $scope.logoDivHeight = $window.innerHeight - 381;
        $scope.ratings = {
            TOTAL_FEEDBACK: 0,
            AVGRATING: 0,
            PRODUCT_QUALITY: 0,
            QUANTITY_DELIVERED: 0,
            SERVICE: 0,
            FACILITIES: 0,
            CLEANINESS: 0,
            CLEANTOILET: 0
        }

        $scope.dealer_Profile = "";



        $scope.settings = {
            lang: $scope.language,
            OldPswd: "",
            NewPswrd: "",
            CPswrd: ""
        };


        $scope.rating_AR_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.AVGRATING,
            minRating: 0,
            readOnly: true
        };

        $scope.rating_PQ_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.PRODUCT_QUALITY,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_QD_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.QUANTITY_DELIVERED,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_S_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.SERVICE,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_CL_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.CLEANINESS,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_F_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.FACILITIES,
            minRating: 0,
            readOnly: true
        };
        $scope.rating_CT_Object = {
            iconOn: 'ion-ios-star',
            iconOff: 'ion-ios-star-outline',
            iconOnColor: 'rgb(1, 87, 155)',
            iconOffColor: 'rgb(1, 87, 155)',
            rating: $scope.ratings.CLEANTOILET,
            minRating: 0,
            readOnly: true
        };





        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });

        $scope.$on('$ionicView.enter', function () {
            $scope.dealer = userService.getUser();
            initiLiseValues();
            loadRatings();
            //registerInMcs();
        });


        function loadRatings() {
            $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/RDBXS/RSRatSum/?roCode=" + $scope.dealer.rocode)
                .success(function (data, status) {
                    if (data) {
                        $scope.ratings = data.dbRatingSummaryOutput[0];
                        if (JSON.stringify($scope.ratings.AVGRATING).indexOf("@nil") > -1) {
                            $scope.ratings.AVGRATING = "0";
                        }
                        if (JSON.stringify($scope.ratings.PRODUCT_QUALITY).indexOf("@nil") > -1) {
                            $scope.ratings.PRODUCT_QUALITY = "0";
                        }
                        if (JSON.stringify($scope.ratings.QUANTITY_DELIVERED).indexOf("@nil") > -1) {
                            $scope.ratings.QUANTITY_DELIVERED = "0";
                        }
                        if (JSON.stringify($scope.ratings.SERVICE).indexOf("@nil") > -1) {
                            $scope.ratings.SERVICE = "0";
                        }
                        if (JSON.stringify($scope.ratings.CLEANINESS).indexOf("@nil") > -1) {
                            $scope.ratings.CLEANINESS = "0";
                        }
                        if (JSON.stringify($scope.ratings.FACILITIES).indexOf("@nil") > -1) {
                            $scope.ratings.FACILITIES = "0";
                        }
                        if (JSON.stringify($scope.ratings.CLEANTOILET).indexOf("@nil") > -1) {
                            $scope.ratings.CLEANTOILET = "0";
                        }

                        $scope.rating_AR_Object.setRating(Math.floor($scope.ratings.AVGRATING));
                        $scope.rating_PQ_Object.setRating(Math.floor($scope.ratings.PRODUCT_QUALITY));
                        $scope.rating_QD_Object.setRating(Math.floor($scope.ratings.QUANTITY_DELIVERED));
                        $scope.rating_S_Object.setRating(Math.floor($scope.ratings.SERVICE));
                        $scope.rating_CL_Object.setRating(Math.floor($scope.ratings.CLEANINESS));
                        $scope.rating_F_Object.setRating(Math.floor($scope.ratings.FACILITIES));
                        $scope.rating_CT_Object.setRating(Math.floor($scope.ratings.CLEANTOILET));

                    }

                    $ionicLoading.hide();
                }).error(onError);


        }

        function loadRoProfile() {
            if ($scope.dealer.rocode != null) {

                $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/RDBXS/RSRoData/?ro_code=" + $scope.dealer.rocode)
                    .success(function (data) {
                        if (data) {
                            dealerProfile = data.VwMobCustomer[0];
                            for (var key in dealerProfile) {
                                if (JSON.stringify(dealerProfile[key]).indexOf("@nil") > -1) {
                                    dealerProfile[key] = "";
                                }
                            }

                            dealerProfile.indent_reg_no = dealerProfile.telephone;

                            var rocode = "0000" + dealerProfile.rocode;

                            $http.get("https://m.indianoil.in:8443/sap/opu/odata/sap/z_xs_cust_mobile_srv/CustMobileSet?$filter=Kunnr%20eq%20%27" + rocode + "%27")
                                .success(function (data) {
                                    if (data) {
                                        for (var ii = 0; ii < data.d.results.length; ii++) {
                                            if (data.d.results[ii].Mobtyp == "P") {
                                                dealerProfile.indent_reg_no = data.d.results[ii].MobNumber;
                                                break;
                                            }
                                        }
                                    }
                                    $scope.dealer_Profile = dealerProfile;
                                })
                                .error(function () {
                                    alert('Error occured');
                                });

                        }
                    }).error(function () {
                        alert('Error occured');
                    });
            }
        }

        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();

        }

        $scope.slideHasChanged = function (val) {

        }

        $scope.changeView = function (view) {
            userService.setpreviousView("app.home");
            $state.go(view);
        }

        //Modal window for filter
        $ionicModal.fromTemplateUrl('connectModal.html', function (modal) {
            $scope.socialModal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $scope.showSocialModal = function () {
            $scope.socialModal.show();
            var el = document.getElementById("socialLinks");
            el.classList.remove("fadeOutRight");

        }


        $scope.hideSocialModal = function () {

            var el = document.getElementById("socialLinks");
            //el.classList.remove("my-class");
            el.classList.add("fadeOutRight");
            $timeout(function () {
                $scope.socialModal.hide();
            }, 400);

        }


        $ionicModal.fromTemplateUrl('dealerProfile.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $scope.hideLubeTips = function () {
            $scope.modal.hide();
        }

        $scope.showDProfile = function () {
            $scope.modal.show();
            loadRoProfile();
        }


        $scope.logOut = function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Processing'
            });
            window.localStorage.setItem('dealerCode', "");
            window.localStorage.setItem('dealerPassword', "");
            $state.go('login');
            $timeout(function () {
                $ionicLoading.hide();
            }, 2000);
        }

        $scope.goMpowerHome = function () {
            $state.go('app.home');
        }

        $scope.openLinks = function (url) {
            window.open(url, '_system', 'location=no');
        }

        function initiLiseValues() {
            $scope.lShow = false;
            $scope.pShow = false;
            $scope.languageUpdateResult = "";
            $scope.passrdUpdateResult = "";
            $scope.lShow = false;
            $scope.pShow = false;
            $scope.languageUpdateResult = "";
            $scope.passrdUpdateResult = "";
            $scope.logoDivHeight = $window.innerHeight - 381;
            $scope.user = userService.getUser();
            $scope.settings = {
                lang: $scope.language,
                OldPswd: "",
                NewPswrd: "",
                CPswrd: ""
            };
        }

    })

    .controller('xSparshRSPController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });

        $scope.isRightFound = false;

        $scope.$on('$ionicView.enter', function () {
            $scope.tabNumber = 1;
            $scope.isPriceSeenAcknowledgedToday = true;
            $scope.dealer = userService.getUser();
            $scope.isPriceSeenAcknowledged = true;


            if (userService.getpreviousView() == "app.home") {
                var rocode = $scope.dealer.rocode;

                var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_SP_new_SRV/ZMACUSTRSPSet?$filter=Soldto%20eq%20%27" + rocode + "%27%20&$format=json";
                $http.get(url)
                    .success(function (data, status) {
                        $scope.custRsp = data.d.results;
                        for (var i = 0; i < $scope.custRsp.length; i++) {
                            if ($scope.custRsp[i] && $scope.custRsp[i].Rsp) {
                                $scope.custRsp[i].Rsp = parseFloat($scope.custRsp[i].Rsp).toFixed(2);
                            } else {
                                $scope.custRsp[i].Rsp = "Not Available";
                            }

                            if ($scope.custRsp[i] && $scope.custRsp[i].Invamt) {
                                $scope.custRsp[i].Invamt = parseFloat($scope.custRsp[i].Invamt).toFixed(2);
                            } else {
                                $scope.custRsp[i].Invamt = "Not Available";
                            }

                        }
                        $ionicLoading.hide();
                    }).error(onError);
            } else if (userService.getcurrentView() == "oldrsp") {
                var rocode = "0000" + $scope.dealer.rocode;
                $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/RDBXS/RSRspLog/?roCode=" + rocode)
                    .success(function (data, status) {
                        if (data) {
                            $scope.oldRsp = data.dbRSPLogOutput;

                            var ii = 0;
                            var kk = 0;
                            $scope.oldRspData = [];


                            while (ii < data.dbRSPLogOutput.length && kk < 5) {
                                var dd = data.dbRSPLogOutput[ii].datab;
                                var tempOldRsp = {
                                    datab: "fdfdfd1",
                                    productPrice: [
                                        {
                                            sms_cd: "MS",
                                            netwr: "70"
                                        }
                                    ]
                                };
                                tempOldRsp.datab = data.dbRSPLogOutput[ii].datab;
                                var tempPPs = [];

                                while (dd == data.dbRSPLogOutput[ii].datab) {
                                    var tempPP = {
                                        sms_cd: "MS",
                                        netwr: "70"
                                    };
                                    tempPP.sms_cd = data.dbRSPLogOutput[ii].sms_cd;
                                    tempPP.netwr = data.dbRSPLogOutput[ii].netwr;
                                    tempPPs.push(tempPP);
                                    ii++;
                                }
                                tempOldRsp.productPrice = tempPPs;
                                console.log("Temp :: " + JSON.stringify(tempOldRsp));
                                $scope.oldRspData.push(tempOldRsp);
                                console.log(JSON.stringify($scope.oldRspData));
                                kk++;
                            }

                            console.log(JSON.stringify($scope.oldRspData));

                        }
                        $ionicLoading.hide();
                    }).error(onError);
            } else if (userService.getcurrentView() == "omcrsp") {
                var rocode = $scope.dealer.rocode;
                $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/RDBXS/RSROinTA/?roCode=" + rocode)
                    .success(function (data, status) {
                        if (data) {
                            $scope.omcRspData = data.MvCowiseRo;
                        }
                        $ionicLoading.hide();
                    }).error(onError);
            } else {
                $ionicLoading.hide();
            }
        });


        $scope.showTodayPrice = function () {
            $scope.tabNumber = 1;
        };

        $scope.showTomorrowPrice = function () {
            $scope.tabNumber = 2;

            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSTimeStatus")
                .success(function (data, status) {
                    if (data && data.dbTomPriceOutput && data.dbTomPriceOutput[0]) {
                        if (data.dbTomPriceOutput[0].status == "false") {

                            $scope.isRightFound = false;
                            $scope.errorContent = "To be declared";
                            $ionicLoading.hide();


                        } else {
                            $scope.isRightFound = true;
                            $scope.errorContent = "";
                            loadTomorrowPrice();
                        }

                    } else {
                        $scope.isRightFound = false;
                        $scope.errorContent = "Problem occured while getting prices";
                        $ionicLoading.hide();
                    }
                }).error(function () {
                    $ionicLoading.hide();
                });



        };
        function loadTomorrowPrice() {
            var currentDate = new Date();
            currentDate.setDate(currentDate.getDate() + 1);

            var day = currentDate.getDate();
            var month = currentDate.getMonth() + 1;
            var year = currentDate.getFullYear();
            var hoursForCheck = currentDate.getHours();
            if (hoursForCheck >= 0 && hoursForCheck < 6) {
                var dt = new Date();
                var monthT = dt.getMonth() + 1;
                var dayT = dt.getDate();
                var yearT = dt.getFullYear();
                $scope.efctDate = dayT.toString() + "-" + monthT.toString() + "-" + yearT.toString();
            } else {
                $scope.efctDate = day.toString() + "-" + month.toString() + "-" + year.toString();
            }
            var dateString = year.toString() + "-" + month.toString() + "-" + day.toString();

            var rocode = "0000" + $scope.dealer.rocode;

            //old service
            //var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_SP_new_SRV/ZMACUSTRSPSet?$filter=Soldto%20eq%20%27" + rocode + "%27%20and%20Prcdate%20eq%20datetime%27" + dateString + "T00:00:00%27%20&$format=json";
            var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_SP_new_SRV/SalesPriceSet?$filter=Soldto%20eq%20%27" + rocode + "%27%20and%20Prcdate%20eq%20datetime%27" + dateString + "T00:00:00%27%20&$format=json";

            $http.get(url)
                .success(function (data, status) {
                    //Hide below after testing
                    //data.d.results[0].Flag = "Y";
                    if (data.d.results.length > 0 && data.d.results[0].Flag != "") {
                        $scope.custTomorrowRsp = data.d.results;
                        for (var i = 0; i < $scope.custTomorrowRsp.length; i++) {

                            if ($scope.custTomorrowRsp[i] && $scope.custTomorrowRsp[i].Rsp) {
                                $scope.custTomorrowRsp[i].Rsp = parseFloat($scope.custTomorrowRsp[i].Rsp).toFixed(2);
                            } else {
                                $scope.custTomorrowRsp[i].Rsp = "Not Available";
                            }

                            if ($scope.custTomorrowRsp[i] && $scope.custTomorrowRsp[i].Invamt) {
                                $scope.custTomorrowRsp[i].Invamt = parseFloat($scope.custTomorrowRsp[i].Invamt).toFixed(2);
                            } else {
                                $scope.custTomorrowRsp[i].Invamt = "Not Available";
                            }

                        }



                        $ionicLoading.hide();

                        $scope.tabNumber = 2;

                    } else {
                        $scope.isRightFound = false;
                        $scope.errorContent = "To be declared";
                        $ionicLoading.hide();
                    }


                }).error(function () {
                    alert('Problem occured');
                    $ionicLoading.hide();
                });
        }




        $ionicModal.fromTemplateUrl('addOmcRsp.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $scope.hideOmcRsp = function () {
            $scope.modal.hide();
        }

        $scope.omcRsp = function () {
            userService.setpreviousView('rsp');
            userService.setcurrentView('omcrsp');
            $state.go('omcrsp');
        }

        $scope.addOmcRsp = function (rsp) {
            $scope.currentOmc = {
                roCode: rsp.roCode,
                roName: rsp.roName,
                companyName: rsp.companyName,
                msPrice: "0",
                hsPrice: "0",
                fromDate: "",
                createdBy: rsp.roCode
            };
            $scope.modal.show();
        }

        $scope.addRspOmc = function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            var hasError = false;
            var errorMessage = "";
            if ($scope.currentOmc.fromDate == null || $scope.currentOmc.fromDate == "0" || $scope.currentOmc.fromDate == "" || $scope.currentOmc.fromDate == "0000-00-00") {
                hasError = true;
                errorMessage = "Select date";
            } else {
                var dd = new Date($scope.currentOmc.fromDate);

                var tDate = new Date();

                if (dd > tDate) {
                    hasError = true;
                    errorMessage = "Future date not allowed";
                } else {
                    var month = (dd.getMonth() + 1).toString();
                    if (month.length === 1) {
                        month = "0" + month;
                    }
                    var day = dd.getDate().toString();
                    if (day.length === 1) {
                        day = "0" + day;
                    }

                    var ddString = dd.getFullYear() + "-" + month + "-" + day;
                    $scope.currentOmc.fromDate = ddString;
                }
            }

            if (!hasError && ($scope.currentOmc.msPrice == "" || $scope.currentOmc.hsPrice == ""
                || $scope.currentOmc.msPrice == "0" || $scope.currentOmc.hsPrice == "0")) {
                hasError = true;
                errorMessage = "Enter valid price";
            }

            if (!IsFloat($scope.currentOmc.msPrice) || !IsFloat($scope.currentOmc.hsPrice)) {
                hasError = true;
                errorMessage = "Enter valid price";
            }

            function IsFloat(fVal) {
                var fParsedVal; //our internal converted float value

                fParsedVal = parseFloat(fVal);

                if (isNaN(fParsedVal) || Infinity == fParsedVal || -Infinity == fParsedVal) //sanity check - guard against empty strings and max/min values
                    return false;
                else
                    return !!(fVal % 1); //true only if there is a fractional value after the mod op; the !! returns the opposite value of the op which reflects the function's return value
            }

            if (!hasError) {
                $http.post('https://xsparsh.indianoil.in:8443/soa-infra/resources/default/RDBXS/RSOmcRsp/?roCode=' + $scope.currentOmc.roCode +
                    '&msPrice=' + $scope.currentOmc.msPrice +
                    '&hsPrice=' + $scope.currentOmc.hsPrice +
                    '&dateFrom=' + $scope.currentOmc.fromDate +
                    '&createdBy=' + $scope.currentOmc.roCode).success(function (data, status) {

                        //alert(JSON.stringify(data));
                        if (status == 204) {
                            var alertPopup = $ionicPopup.alert({
                                title: 'Success',
                                template: 'RSP updated'
                            });
                            $scope.modal.hide();
                        } else {
                            var alertPopup = $ionicPopup.alert({
                                title: 'Error',
                                template: 'Some Internal Error Occurred'
                            });
                        }
                        $ionicLoading.hide();
                    }).error(onError);
            } else {
                var alertPopup = $ionicPopup.alert({
                    title: 'Validation',
                    template: errorMessage
                });
                $ionicLoading.hide();
            }

        }

        $scope.oldRsp = function () {
            userService.setpreviousView('rsp');
            userService.setcurrentView('oldrsp');
            $state.go('oldrsp');
        }

        function onError(data) {
            $scope.error = true;
            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'Some Internal Error Occurred'
            });
            $ionicLoading.hide();
        }


        $scope.goBack = function () {
            var preView = userService.getpreviousView();
            $state.go(preView);
        }

        $scope.goBackRsp = function () {
            $ionicLoading.hide();
            userService.setpreviousView('app.home');
            $state.go('rsp');
        }
    })

    .controller('xSparshPaymentController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform, userService, $ionicHistory) {

        //Default two wheeler vechicles air pressures will be shown

        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });



        $scope.$on('$ionicView.enter', function () {
            $scope.dealer = userService.getUser();
            var rocode = "0000" + $scope.dealer.rocode;
            $http.get("https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_PAYMENTS_SRV/ZMACUSTPAYSet?$skip=0&$top=100&$inlinecount=allpages&$filter=Kunnr%20eq%20%27" + rocode + "%27&$format=json")
                .success(function (data, status) {
                    if (data) {
                        $scope.custPayment = data.d.results;
                        for (i = 0; i < $scope.custPayment.length; i++) {
                            var tt = $scope.custPayment[i].Cpudt.substring(6, $scope.custPayment[i].Cpudt.length - 2);
                            var dd = new Date(parseInt(tt));
                            $scope.custPayment[i].Cpudt = dd.toString();
                        }
                    } else {
                        $scope.custPayment = {};
                    }

                    $ionicLoading.hide();
                }).error(onError);

        });

        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }


        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('xSparshSalesController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform, userService, $ionicHistory) {

        //Default two wheeler vechicles air pressures will be shown

        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });



        $scope.months = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", "Total"];
        $scope.selectedProduct = "MS";

        $scope.$on('$ionicView.enter', function () {
            $scope.dealer = userService.getUser();
            var rocode = $scope.dealer.rocode;

            $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/RDBXS/RSROST?roCode=" + rocode)
                .success(function (data, status) {
                    if (data) {
                        $scope.sales = data.dbROSTOutput;


                        for (var ii = 0; ii < $scope.sales.length; ii++) {
                            $scope.sales[ii].YYYYMM = parseInt($scope.sales[ii].YYYYMM.toString().substring(4)) - 1;
                            if (JSON.stringify($scope.sales[ii].ms_target).indexOf("@nil") > -1) {
                                $scope.sales[ii].ms_target = 0;
                            }
                            if (JSON.stringify($scope.sales[ii].hsd_target).indexOf("@nil") > -1) {
                                $scope.sales[ii].hsd_target = 0;
                            }
                            if (JSON.stringify($scope.sales[ii].xp_target).indexOf("@nil") > -1) {
                                $scope.sales[ii].xp_target = 0;
                            }
                            if (JSON.stringify($scope.sales[ii].xm_target).indexOf("@nil") > -1) {
                                $scope.sales[ii].xm_target = 0;
                            }
                        }

                        var tempTotalSales = {
                            "RO_CODE": rocode,
                            "YYYYMM": 12,
                            "MS_SALES_LY": 0,
                            "MS_SALES": 0,
                            "ms_target": 0,
                            "HSD_SALES_LY": 0,
                            "HSD_SALES": 0,
                            "hsd_target": 0,
                            "XP_SALES_LY": 0,
                            "XP_SALES": 0,
                            "xp_target": 0,
                            "XM_SALES_LY": 0,
                            "XM_SALES": 0,
                            "xm_target": 0
                        }

                        for (var ii = 0; ii < $scope.sales.length; ii++) {
                            tempTotalSales.MS_SALES_LY += $scope.sales[ii].MS_SALES_LY;
                            tempTotalSales.MS_SALES += $scope.sales[ii].MS_SALES;
                            tempTotalSales.ms_target += $scope.sales[ii].ms_target;
                            tempTotalSales.HSD_SALES_LY += $scope.sales[ii].HSD_SALES_LY;
                            tempTotalSales.HSD_SALES += $scope.sales[ii].HSD_SALES;
                            tempTotalSales.hsd_target += $scope.sales[ii].hsd_target;
                            tempTotalSales.XP_SALES_LY += $scope.sales[ii].XP_SALES_LY;
                            tempTotalSales.XP_SALES += $scope.sales[ii].XP_SALES;
                            tempTotalSales.xp_target += $scope.sales[ii].xp_target;
                            tempTotalSales.XM_SALES_LY += $scope.sales[ii].XM_SALES_LY;
                            tempTotalSales.XM_SALES += $scope.sales[ii].XM_SALES;
                            tempTotalSales.xm_target += $scope.sales[ii].xm_target;
                        }
                        $scope.sales.push(tempTotalSales);

                    } else {
                        $scope.sales = {};
                    }
                    $ionicLoading.hide();
                }).error(onError);

        });

        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }


        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('xSparshTASalesController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform, userService, $ionicHistory) {

        //Default two wheeler vechicles air pressures will be shown

        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });



        $scope.selectedMonth = "";
        $scope.selectedMonthNew = {
            mv: ""
        };

        $scope.$on('$ionicView.enter', function () {
            $scope.dealer = userService.getUser();
            var rocode = $scope.dealer.rocode;
            $scope.sales = [];
            $scope.selfSale = {};
            $scope.selectedMonth = "0";
            $scope.selectedMonthNew.mv = "0";
            $scope.monthArray = [];
            var dd = new Date();
            var months = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];

            dd.setMonth(dd.getMonth() - 1);
            for (var ii = 0; ii < 6; ii++) {
                var tempMonth = {
                    monthName: "Jan 2016",
                    monthVal: "201601"
                };
                var monthVal = (dd.getMonth() + 1);
                var monthName = months[monthVal - 1] + " " + dd.getFullYear();
                monthVal = monthVal.toString();
                if (monthVal.length === 1) {
                    monthVal = "0" + monthVal;
                }
                monthVal = dd.getFullYear() + monthVal;
                tempMonth.monthName = monthName;
                tempMonth.monthVal = monthVal;


                $scope.monthArray.push(tempMonth);

                dd.setMonth(dd.getMonth() - 1);

            }
            console.log(JSON.stringify($scope.monthArray));
            $ionicLoading.hide();

            //getTASales($scope.selectedMonth);


        });

        $scope.showMonthSale = function () {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            getTASales($scope.selectedMonthNew.mv);
        }

        function getTASales(month) {

            if (!(month == "0")) {

                var rocode = $scope.dealer.rocode;
                $scope.sales = [];
                $scope.selfSale = {
                    company: "",
                    companyName: "",
                    custcodemap: "",
                    custName: "",
                    tradingAreaCode: "",
                    tradingareaName: "",
                    yyyymm: "",
                    msSales: "",
                    hsdSales: ""
                };
                $http.get("https://xsparsh.indianoil.in:8443/soa-infra/resources/default/RDBXS/RSTASales?roCode=" + rocode + "&month=" + month)
                    .success(function (data, status) {
                        if (data) {
                            var tempSales = data.MvCustSalesdata;
                            for (var ii = 0; ii < tempSales.length; ii++) {
                                if (tempSales[ii].custcodemap == $scope.dealer.rocode) {
                                    $scope.selfSale = tempSales[ii];
                                    console.log(JSON.stringify($scope.selfSale));
                                } else {
                                    $scope.sales.push(tempSales[ii]);
                                }
                            }
                        } else {
                            $scope.sales = [];
                        }
                        $ionicLoading.hide();
                    }).error(onError);
            }


        }
        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }


        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('xSparshBalanceController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform, userService, $ionicHistory) {

        //Default two wheeler vechicles air pressures will be shown

        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });



        $scope.$on('$ionicView.enter', function () {
            $scope.dealer = userService.getUser();
            var rocode = $scope.dealer.rocode;
            $http.get("https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_BAL_SRV/CcaBal1Set?$skip=0&$top=100&$inlinecount=allpages&$filter=Customer%20eq%20%27" + $scope.dealer.rocode + "%27&$format=json")
                .success(function (data, status) {
                    $scope.custBalance = data.d.results;
                    $ionicLoading.hide();
                }).error(onError);

        });

        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }


        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('xSparshCDController', function ($scope, $state, $http, $ionicLoading, $timeout, $ionicPlatform, userService, $ionicHistory) {

        //Default two wheeler vechicles air pressures will be shown

        $ionicLoading.show({
            template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
        });


        $scope.selectedProduct = "0";

        $scope.$on('$ionicView.enter', function () {
            $scope.dealer = userService.getUser();
            var rocode = "0000" + $scope.dealer.rocode;
            $http.get("https://m.indianoil.in:8443/sap/opu/odata/sap/Z_PM_DAILY_SALES_SRV/DailysalecustSet?$filter=Kunnr%20eq%20%27" + rocode + "%27&$format=json")
                .success(function (data, status) {
                    $scope.products = [];


                    if (data) {
                        $scope.currentDispatch = data.d.results;
                        var dd = new Date();
                        $scope.currentDay = dd.getDate();

                        for (var ii = 0; ii < $scope.currentDispatch.length; ii++) {
                            var pp = {
                                "matCode": "0",
                                "matName": "matName"
                            };
                            pp.matCode = $scope.currentDispatch[ii].Matnr;
                            pp.matName = $scope.currentDispatch[ii].Maktx;
                            $scope.products.push(pp);
                        }

                    } else {
                        $scope.currentDispatch = [];
                        $scope.products = [];
                    }

                    $ionicLoading.hide();
                }).error(onError);

        });

        function onError(data) {
            $scope.error = true;
            $ionicLoading.hide();
        }


        $scope.goBack = function () {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }
    })

    .controller('CashlessSummaryController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $scope.employee = userService.getUser();
        $scope.$on('$ionicView.enter', function () {

            $scope.employee = userService.getUser();
            $scope.tabNumber = 1;
            //loadCustomerCentricData();
        });
        $scope.loadCustomerCentricData = function () {

            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            var serviceDetails = {};
            var empRole = $scope.employee.empRole;
            serviceDetails.url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSCashlessSummary";
            if (empRole == "FO-RS") {

                serviceDetails.paramKey = "sales_group";
                serviceDetails.empHier = "SG";
                serviceDetails.nodename = "FO";
                serviceDetails.nodevalue = $scope.employee.salesGroup;
                serviceDetails.paramName = $scope.employee.salesArea;

            } else if (empRole == "DO-RS") {

                serviceDetails.paramKey = "do_code";
                serviceDetails.empHier = "DO";
                serviceDetails.nodename = $scope.employee.locCode;
                serviceDetails.nodevalue = "1101";

                serviceDetails.paramName = $scope.employee.locName;

            } else if (empRole == "SO-RS") {

                serviceDetails.paramKey = "so_code";
                serviceDetails.empHier = "SO";
                serviceDetails.nodename = "SO";
                serviceDetails.nodevalue = $scope.employee.locCode;
                serviceDetails.paramName = $scope.employee.locName;


            } else if (empRole == "HO-RS" || empRole == "IS") {

                serviceDetails.paramKey = "";
                serviceDetails.empHier = "HO";
                serviceDetails.nodename = "HO";
                serviceDetails.nodevalue = "";
                serviceDetails.paramName = "All India";
            }

            $scope.serviceDetails = serviceDetails;
            var urlS = serviceDetails.url + "?nodename=" + serviceDetails.nodename + "&nodevalue=" + serviceDetails.nodevalue;
            $http.get(urlS)
                .success(function (data, status) {
                    if (data) {
                        $scope.ccData = data.CSR_DATA.CSR_DATA_Row[0];
                    } else {
                        alert("No Data Found");
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                $scope.error = true;
                $ionicLoading.hide();
            }
        }





        $scope.loadCustomerCentricData();


        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('FOViewController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $scope.employee = userService.getUser();

        $scope.$on('$ionicView.enter', function () {

            $scope.employee = userService.getUser();
            $scope.tabNumber = 1;

            //loadCustomerCentricData();
        });
        $scope.loadCustomers = function () {

            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            var url = "https://xsparsh.indianoil.in:8443/soa-infra/resources/default/MPower/RSRoDsrList?sales_group=" + $scope.employee.salesGroup;

            $http.get(url)
                .success(function (data, status) {
                    if (data) {
                        $scope.customersData = data.dbDSRroListOutput;
                    } else {
                        alert("No Data Found");
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                $scope.error = true;
                $ionicLoading.hide();
            }
        }

        $scope.chnageCDate = function (ro) {
            userService.setRoDetails(ro);
            $state.go("Customer_Data");
        }

        $scope.customerFilter = function (val) {

            if ($scope.customerSearchString && $scope.customerSearchString.length > 0) {
                if (val.DEALER.toLowerCase().indexOf($scope.customerSearchString.toLowerCase()) < 0) {
                    return false;
                }

                return true;
            } else {
                return true;
            }
        }




        $scope.loadCustomers();


        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('ConsumerController', function ($scope, $state, $stateParams, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {


        $scope.$on('$ionicView.enter', function () {
            $scope.IsBal = false;
            $scope.IsPay = false;
            $scope.IsIndent = false;
            $scope.IsSalTr = false;
            $scope.IsExDepo = false;
            $scope.IsOrderStatusAvailable = true;
            $scope.employee = userService.getUser();
            $scope.Exdepoprice = '';
            $scope.consumerno = "";

            $scope.totalSales = [];
            var date = new Date();
            $scope.SalesTrackerFromDate = {
                val: date
            };
            $scope.SalesTrackerToDate = {
                val: date
            };
            $scope.data = {
                salesGroup: $scope.employee.salesGroup,
                consumerno: ""
            };
            $scope.exdepo = {
                plCode: "",
                mCode: ""
            };



            $scope.tab = 0;
            $scope.sTrackerTab = 1;
            $scope.consumerno = "";

            if (JSON.stringify($scope.employee.salesGroup).indexOf('@nil') > -1 || $scope.employee.salesGroup == "") {
                $scope.IsOrderStatusAvailable = false;
            }

        });



        $scope.get_balance = function () {

            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            if ($scope.data.consumerno == "" || !($scope.data.consumerno.toString()) || $scope.data.consumerno.toString().length < 6) {
                alert("Enter valid consumer number");
                $ionicLoading.hide();
            } else {
                $scope.Custbalance = [];
                var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_MP_SERVICES_SRV/ZMPCUSTBALSet?$filter=Customer%20eq%20%27" + $scope.data.consumerno + "%27&$format=json";
                $http.get(url)
                    .success(function (data, status) {
                        if (data && data.d && data.d.results && data.d.results.length > 0) {
                            $scope.Custbalance = data.d.results;
                            $scope.consumer_name = $scope.Custbalance[0].Name;
                            for (var i = 0; i < $scope.Custbalance.length; i++) {
                                if ($scope.Custbalance[i].Balance > 0) {
                                    $scope.Custbalance[i].Balance = "(D) ₹" + (Math.abs($scope.Custbalance[i].Balance)).toString();
                                } else if ($scope.Custbalance[i].Balance < 0) {
                                    $scope.Custbalance[i].Balance = "(C) ₹" + (Math.abs($scope.Custbalance[i].Balance)).toString();
                                } else {
                                    $scope.Custbalance[i].Balance = "(D) ₹" + $scope.Custbalance[i].Balance;
                                }

                            }
                            $scope.tab = 1;
                            $scope.showConsumerWindow();
                        } else {
                            alert("No Data Found.  Check whether consumer number is correct or not.");
                        }
                        $ionicLoading.hide();

                    }).error(onError);
                function onError(data) {
                    alert("Error Occured. Check whether consumer number is correct or not.");
                    $ionicLoading.hide();
                }
            }

        }

        $scope.show_alert = function () {
            var myPopup = $ionicPopup.alert({
                title: 'Alert',
                template: "Enter a consumer no."
            });
        }

        $scope.get_payments = function () {

            $scope.Custpayments = [];


            if ($scope.data.consumerno == "" || !($scope.data.consumerno.toString()) || $scope.data.consumerno.toString().length < 6) {
                alert("Enter valid consumer number");
                $ionicLoading.hide();
            } else {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });
                var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_MP_SERVICES_SRV/ZMPPAYMENTSSet?$filter=Kunnr%20eq%20%270000" + $scope.data.consumerno + "%27&$format=json";
                $http.get(url)
                    .success(function (data, status) {
                        if (data && data.d && data.d.results && data.d.results.length > 0) {
                            $scope.Custpayments = data.d.results;
                            $scope.consumer_name = "";
                            for (i = 0; i < $scope.Custpayments.length; i++) {
                                $scope.Custpayments[i].Cpudt = Format($scope.Custpayments[i].Cpudt);
                            }
                            $scope.tab = 2;
                            $scope.showConsumerWindow();
                        } else {
                            alert("No Data Found. Check whether consumer number is correct or not.");
                        }
                        $ionicLoading.hide();
                        $scope.pay_flag = true;
                    }).error(onError);
                function onError(data) {
                    alert("Error Occured");
                    $ionicLoading.hide();
                }
            }
        }


        $scope.get_exdepoprice = function () {

            if ($scope.data.consumerno == "" || !($scope.data.consumerno.toString()) || $scope.data.consumerno.toString().length < 6) {
                alert("Enter valid consumer number");
                $ionicLoading.hide();
            } else if ($scope.exdepo.plCode == "" || !($scope.exdepo.plCode.toString()) || $scope.exdepo.plCode.toString().length == 0) {
                alert("Enter Valid Plant Code");
            } else if ($scope.exdepo.mCode == "" || !($scope.exdepo.mCode.toString()) || $scope.exdepo.mCode.toString().length == 0) {
                alert("Enter Valid Material Code");
            } else {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });
                var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_MP_SERVICES_SRV/ZMPCONSPRICINGSet?$filter=Soldto%20eq%20%270000" + $scope.data.consumerno + "%27%20and%20Shipto%20eq%20%270000" + $scope.data.consumerno + "%27%20and%20Plant%20eq%20%27" + $scope.exdepo.plCode + "%27%20and%20Matnr%20eq%20%27" + $scope.exdepo.mCode + "%27";
                $http.get(url)
                    .success(function (data, status) {
                        if (data) {
                            $scope.Exdepoprice = data.d.results[0];
                            $scope.consumer_name = $scope.Exdepoprice.Custname;
                            $scope.tab = 3;
                            $scope.showConsumerWindow();
                        } else {
                            alert("No Data Found");
                        }
                        $ionicLoading.hide();
                    }).error(onError);
                function onError(data) {
                    alert("Error Occured");
                    $ionicLoading.hide();
                }
            }


        }

        $scope.get_salesTracker = function () {
            if (validateSalesTrackerValues()) {
                $scope.showSalesTrckerWindow();
                loadTotalSales();
            }
        }


        function Format(date) {


            var res = date.substring(6, date.length - 2);
            // alert(res);
            var theDate = new Date(Number(res));
            var dateString = theDate.toGMTString();
            return dateString.substring(4, dateString.length - 12);

        }


        $scope.get_indentTracker = function () {
            if ($scope.data.salesGroup == "" || $scope.data.salesGroup == null) {
                alert("Please enter Sales Group");
            } else {
                $state.go("ConsumerIndentTracker", { salesGroup: $scope.data.salesGroup.toString().toUpperCase() });
            }

        }
        $scope.showBalOptions = function () {
            $scope.IsBal = !($scope.IsBal);
            if ($scope.IsBal) {
                $scope.IsPay = false;
                $scope.IsIndent = false;
                $scope.IsSalTr = false;
                $scope.IsExDepo = false;
            }
        }

        $scope.showPayOptions = function () {
            $scope.IsPay = !($scope.IsPay);
            if ($scope.IsPay) {
                $scope.IsBal = false;
                $scope.IsIndent = false;
                $scope.IsSalTr = false;
                $scope.IsExDepo = false;
            }
        }

        $scope.showIndentTrackerOptions = function () {
            $scope.IsIndent = !($scope.IsIndent);
            if ($scope.IsIndent) {
                $scope.IsBal = false;
                $scope.IsPay = false;
                $scope.IsSalTr = false;
                $scope.IsExDepo = false;
            }
        }

        $scope.showSalesTrackerOptions = function () {
            $scope.IsSalTr = !($scope.IsSalTr);
            if ($scope.IsSalTr) {
                $scope.IsBal = false;
                $scope.IsPay = false;
                $scope.IsIndent = false;
                $scope.IsExDepo = false;
            }
        }

        $scope.showExdepoOptions = function () {
            $scope.IsExDepo = !($scope.IsExDepo);
            if ($scope.IsExDepo) {
                $scope.IsBal = false;
                $scope.IsPay = false;
                $scope.IsIndent = false;
                $scope.IsSalTr = false;
            }
        }
        $ionicModal.fromTemplateUrl('ConsumerData.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });

        $ionicModal.fromTemplateUrl('salesTracker.html', function (modal) {
            $scope.modalSalessTracker = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });




        $scope.showConsumerWindow = function () {
            $scope.modal.show();
        }

        $scope.hideConsumerWindow = function () {
            $scope.modal.hide();
        }

        $scope.showSalesTrckerWindow = function () {
            $scope.modalSalessTracker.show();
            loadTotalSales();
        }

        $scope.hideSalesTrckerWindow = function () {
            $scope.modalSalessTracker.hide();
        }

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }

        $scope.showsTrackerTab = function (val) {
            if (val == 1) {
                $scope.sTrackerTab = 1;
                loadTotalSales();
            } else if (val == 2) {
                $scope.sTrackerTab = 2;
                loadProductWiseSales();
            } else if (val == 3) {
                $scope.sTrackerTab = 3;
                loadConsumerWiseSales();
            }
        }
        $scope.emptyConsField = function () {
            $scope.consumerno = "";
        }
        function loadTotalSales() {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            var fromDate = new Date($scope.SalesTrackerFromDate.val);
            var toDate = new Date($scope.SalesTrackerToDate.val);

            fromDate = fromDate.getFullYear() + "-" + (fromDate.getMonth() + 1) + "-" + fromDate.getDate();
            toDate = toDate.getFullYear() + "-" + (toDate.getMonth() + 1) + "-" + toDate.getDate();

            var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_EF_SALES_TRACKER_SRV/ZEFSALESDSSet?$filter=Vkgrp%20eq%20%27" + $scope.data.salesGroup.toString().toUpperCase() + "%27%20and%20IDateFrom%20eq%20datetime%27" + fromDate + "T00:00:00%27%20and%20IDateTo%20eq%20datetime%27" + toDate + "T00:00:00%27";
            $http.get(url)
                .success(function (data, status) {
                    if (data && data.d && data.d.results && data.d.results.length > 0) {
                        $scope.totalSales = data.d.results;
                    } else {
                        alert("No Data Found.");
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                alert("Error Occured");
                $ionicLoading.hide();
            }
        }
        function loadProductWiseSales() {
            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });
            $scope.products = [];
            var fromDate = new Date($scope.SalesTrackerFromDate.val);
            var toDate = new Date($scope.SalesTrackerToDate.val);

            fromDate = fromDate.getFullYear() + "-" + (fromDate.getMonth() + 1) + "-" + fromDate.getDate();
            toDate = toDate.getFullYear() + "-" + (toDate.getMonth() + 1) + "-" + toDate.getDate();

            var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_EF_SALES_TRACKER_SRV/ZEFSALESMSSet?$filter=Vkgrp%20eq%20%27" + $scope.data.salesGroup.toString().toUpperCase() + "%27%20and%20IDateFrom%20eq%20datetime%27" + fromDate + "T00:00:00%27%20and%20IDateTo%20eq%20datetime%27" + toDate + "T00:00:00%27";
            $http.get(url)
                .success(function (data, status) {
                    if (data && data.d && data.d.results && data.d.results.length > 0) {
                        $scope.productWiseSales = data.d.results;
                        for (var i = 0; i < $scope.productWiseSales.length; i++) {
                            if ($scope.products.indexOf($scope.productWiseSales[i].Maktx) < 0) {
                                $scope.products.push($scope.productWiseSales[i].Maktx);
                            }
                        }
                        $scope.selecteProduct = $scope.products[0];
                    } else {
                        alert("No Data Found.");
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                alert("Error Occured");
                $ionicLoading.hide();
            }
        }
        function loadConsumerWiseSales() {

            $ionicLoading.show({
                template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
            });

            var fromDate = new Date($scope.SalesTrackerFromDate.val);
            var toDate = new Date($scope.SalesTrackerToDate.val);

            fromDate = fromDate.getFullYear() + "-" + (fromDate.getMonth() + 1) + "-" + fromDate.getDate();
            toDate = toDate.getFullYear() + "-" + (toDate.getMonth() + 1) + "-" + toDate.getDate();

            var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_EF_SALES_TRACKER_SRV/ZEFSALESCSSet?$filter=Vkgrp%20eq%20%27" + $scope.data.salesGroup.toString().toUpperCase() + "%27%20and%20IDateFrom%20eq%20datetime%27" + fromDate + "T00:00:00%27%20and%20IDateTo%20eq%20datetime%27" + toDate + "T00:00:00%27";
            $http.get(url)
                .success(function (data, status) {
                    if (data && data.d && data.d.results && data.d.results.length > 0) {
                        $scope.consumerWiseSales = data.d.results;
                    } else {
                        alert("No Data Found.");
                    }
                    $ionicLoading.hide();
                }).error(onError);
            function onError(data) {
                alert("Error Occured");
                $ionicLoading.hide();
            }
        }

        function validateSalesTrackerValues() {
            var fromDate = new Date($scope.SalesTrackerFromDate.val);
            var toDate = new Date($scope.SalesTrackerToDate.val);

            var todayDate = new Date();

            fromDate = new Date(fromDate.getFullYear(), fromDate.getMonth(), fromDate.getDate()); //Year, Month, Date
            toDate = new Date(toDate.getFullYear(), toDate.getMonth(), toDate.getDate()); //Year, Month, Date
            todayDate = new Date(todayDate.getFullYear(), todayDate.getMonth(), todayDate.getDate());

            if ($scope.data.salesGroup == "" || $scope.data.salesGroup == null) {
                alert("Please enter Sales Group");
                return false;
            } else if (fromDate > toDate) {
                alert("From date cannot more than To date");
                return false;
            } else if (fromDate > todayDate) {
                alert("From date cannot more than Today date");
                return false;
            } else if (toDate > todayDate) {
                alert("To date cannot more than Today date");
                return false;
            }

            return true;
        }




    })

    .controller('ConsumerIndentTrackerController', function ($scope, $state, $stateParams, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $scope.employee = userService.getUser();
        $scope.$on('$ionicView.enter', function () {

            var date = new Date();
            $scope.IndentFromDate = {
                val: date
            };
            $scope.IndentToDate = {
                val: date
            };

            $scope.customers = [];
            $scope.selection = {
                SO: "",
                DO: "",
                SG: ""
            };
            $scope.customer = {};

            $scope.employee = userService.getUser();
            var serviceDetails = {};
            var empRole = $scope.employee.empRole;
            $scope.showOrderStatus = false;
            $scope.showOrderStatusHier = false;
            $scope.tabNumber = 1;

            $scope.ordersDispatched = [];
            $scope.ordersLoading = [];
            $scope.ordersPending = [];
            $scope.orders = [];
        });

        $ionicModal.fromTemplateUrl('custOrder.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });


        $scope.showCustOrder = function () {
            $scope.modal.show();
        }

        $scope.hideCustOrder = function () {
            $scope.hideSingleOrder();
            $scope.modal.hide();
        }

        $ionicModal.fromTemplateUrl('singleOrder.html', function (modal) {
            $scope.modalOrder = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });


        $scope.showSingleOrder = function () {
            $scope.modalOrder.show();
        }

        $scope.hideSingleOrder = function () {
            $scope.modalOrder.hide();
        }

        $scope.showOrder = function (order) {
            $scope.orderSelected = order;
            $scope.showSingleOrder();
        }

        $scope.showTab = function (val) {
            if (val == 1) {
                $scope.orders = $scope.ordersPending;
            } else if (val == 2) {
                $scope.orders = $scope.ordersLoading;
            } else {
                $scope.orders = $scope.ordersDispatched;
            }
            $scope.tabNumber = val;
        }

        function onError(data) {
            $scope.error = true;
            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'Some Internal Error Occurred'
            });
            $ionicLoading.hide();
        }

        $scope.getVolumeSum = function (items) {
            return items
                .map(function (x) {
                    return x.Qunatity;
                })
                .reduce(function (a, b) {
                    return parseFloat(a) + parseFloat(b);
                });
        };

        $scope.getOrderStatus = function () {
            if (validateValues()) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });


                var fromDate = new Date($scope.IndentFromDate.val);
                var toDate = new Date($scope.IndentToDate.val);

                fromDate = fromDate.getFullYear() + "-" + (fromDate.getMonth() + 1) + "-" + fromDate.getDate();
                toDate = toDate.getFullYear() + "-" + (toDate.getMonth() + 1) + "-" + toDate.getDate();

                $scope.ordersDispatched = [];
                $scope.ordersLoading = [];
                $scope.ordersPending = [];
                $scope.orders = [];

                if ($state.params.salesGroup != "") {
                    var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_MP_SERVICES_SRV/ZMPORDERFLOWSet?$filter=Vkgrp%20eq%20%27" + $state.params.salesGroup + "%27%20and%20DateFrom%20eq%20datetime%27" + fromDate + "T00:00:00%27%20and%20DateTo%20eq%20datetime%27" + toDate + "T00:00:00%27&$format=json"

                    $http.get(url)
                        .success(function (data, status) {
                            if (data) {
                                $scope.orderStatus = data.d.results;
                                for (var i = 0; i < $scope.orderStatus.length; i++) {
                                    if (($scope.orderStatus[i].Comment).toLowerCase() == 'load dispatched') {
                                        $scope.ordersDispatched.push($scope.orderStatus[i]);
                                    } else if (($scope.orderStatus[i].Comment).toLowerCase() == 'delivery created' || ($scope.orderStatus[i].Comment).toLowerCase() == 'shipment created') {
                                        $scope.ordersLoading.push($scope.orderStatus[i]);
                                    } else {
                                        $scope.ordersPending.push($scope.orderStatus[i]);
                                    }
                                }
                                $scope.tabNumber = 1;
                                $scope.orders = $scope.ordersPending;
                            } else {
                                $scope.orderStatus = [];
                            }
                            $scope.showOrderStatusHier = true;
                            generateOrderSummary();

                        }).error(onError);
                } else {
                    alert("Sales Group is empty");
                    $ionicLoading.hide();
                }
            }

        }


        function validateValues() {
            var fromDate = new Date($scope.IndentFromDate.val);
            var toDate = new Date($scope.IndentToDate.val);

            var todayDate = new Date();

            fromDate = new Date(fromDate.getFullYear(), fromDate.getMonth(), fromDate.getDate()); //Year, Month, Date
            toDate = new Date(toDate.getFullYear(), toDate.getMonth(), toDate.getDate()); //Year, Month, Date
            todayDate = new Date(todayDate.getFullYear(), todayDate.getMonth(), todayDate.getDate());


            if (fromDate > toDate) {
                alert("From date cannot more than To date");
                return false;
            } else if (fromDate > todayDate) {
                alert("From date cannot more than Today date");
                return false;
            } else {
                var a = (toDate - fromDate) / (1000 * 3600 * 24);
                if (a > 7) {
                    alert("Difference between two dates cannot be more than seven days.");
                    return false;
                }
            }

            return true;
        }

        $scope.showOrderSummary = function (txt) {
            for (var ii = 0; ii < $scope.orderStatus.length; ii++) {
                var tt = $scope.orderStatus[ii].Ordrno.toString() + $scope.orderStatus[ii].Matcode.toString();
                if (tt == txt) {
                    $scope.orderStatus[ii].show = true;
                } else {
                    $scope.orderStatus[ii].show = false;
                }
            }
        }

        function generateOrderSummary() {

            for (var ii = 0; ii < $scope.orderStatus.length; ii++) {
                $scope.orderStatus[ii].show = false;
                if ($scope.orderStatus[ii].Ordrdt) {
                    var tt = $scope.orderStatus[ii].Ordrdt.substring(6, $scope.orderStatus[ii].Ordrdt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].Ordrdt = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].DelDate) {
                    var tt = $scope.orderStatus[ii].DelDate.substring(6, $scope.orderStatus[ii].DelDate.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].DelDate = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].ShpmntDt) {
                    var tt = $scope.orderStatus[ii].ShpmntDt.substring(6, $scope.orderStatus[ii].ShpmntDt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].ShpmntDt = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].LoadDate) {
                    var tt = $scope.orderStatus[ii].LoadDate.substring(6, $scope.orderStatus[ii].LoadDate.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].LoadDate = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].Reqdeldt) {
                    var tt = $scope.orderStatus[ii].Reqdeldt.substring(6, $scope.orderStatus[ii].Reqdeldt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].Reqdeldt = dd.toString().substring(0, 15);
                }

                $scope.orderStatus[ii].ShpmntTime = $scope.orderStatus[ii].ShpmntTime.substring(2, 4) + ":" + $scope.orderStatus[ii].ShpmntTime.substring(5, 7) + ":" + $scope.orderStatus[ii].ShpmntTime.substring(8, 10);
                $scope.orderStatus[ii].DelTime = $scope.orderStatus[ii].DelTime.substring(2, 4) + ":" + $scope.orderStatus[ii].DelTime.substring(5, 7) + ":" + $scope.orderStatus[ii].DelTime.substring(8, 10);
                $scope.orderStatus[ii].LoadTime = $scope.orderStatus[ii].LoadTime.substring(2, 4) + ":" + $scope.orderStatus[ii].LoadTime.substring(5, 7) + ":" + $scope.orderStatus[ii].LoadTime.substring(8, 10);
                $scope.orderStatus[ii].Erzet = $scope.orderStatus[ii].Erzet.substring(2, 4) + ":" + $scope.orderStatus[ii].Erzet.substring(5, 7) + ":" + $scope.orderStatus[ii].Erzet.substring(8, 10);

            }
            var prodOrderStatus = _.groupBy($scope.orderStatus, "Matcode");

            $scope.prodOrderSummary = [];
            for (var pos in prodOrderStatus) {
                var tempArr = prodOrderStatus[pos];
                var tempObj = {
                    product: "",
                    productName: "",
                    quantityDispatched: 0,
                    quantityLoading: 0,
                    quantityPending: 0
                }
                tempObj.product = prodOrderStatus[pos][0].Matcode;
                tempObj.productName = prodOrderStatus[pos][0].Matdesc;

                for (var jj = 0; jj < tempArr.length; jj++) {
                    if (tempArr[jj].Comment == "Load Dispatched") {
                        tempObj.quantityDispatched += parseFloat(tempArr[jj].Qunatity);
                    } else if (tempArr[jj].Comment == "Delivery Created" || tempArr[jj].Comment == "Shipment Created") {
                        tempObj.quantityLoading += parseFloat(tempArr[jj].Qunatity);
                    } else {
                        tempObj.quantityPending += parseFloat(tempArr[jj].Qunatity);
                    }

                }
                tempObj.quantityDispatched = parseFloat(tempObj.quantityDispatched).toFixed(2);
                tempObj.quantityLoading = parseFloat(tempObj.quantityLoading).toFixed(2);
                tempObj.quantityPending = parseFloat(tempObj.quantityPending).toFixed(2);
                tempObj.Unit = prodOrderStatus[pos][0].Unit;
                $scope.prodOrderSummary.push(tempObj);
            }
            $ionicLoading.hide();
        }

        function onError(data) {
            $scope.error = true;
            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'Some Internal Error Occurred'
            });
            $ionicLoading.hide();
        }

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('ConsumerSalesTracker', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $scope.employee = userService.getUser();
        $scope.$on('$ionicView.enter', function () {


            var date = new Date();
            $scope.IndentFromDate = {
                val: date
            };
            $scope.IndentToDate = {
                val: date
            };

            $scope.customers = [];


            $scope.employee = userService.getUser();
            var empRole = $scope.employee.empRole;

        });

        $ionicModal.fromTemplateUrl('custOrder.html', function (modal) {
            $scope.modal = modal;
        },
            {
                scope: $scope,
                // The animation we want to use for the modal entrance
                animation: 'slide-in-up'
            });


        $scope.showCustOrder = function () {
            $scope.modal.show();
        }

        $scope.hideCustOrder = function () {
            $scope.modal.hide();
        }







        $scope.getOrderStatus = function () {

            if (validateValues()) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });


                var fromDate = new Date($scope.IndentFromDate.val);
                var toDate = new Date($scope.IndentToDate.val);

                fromDate = fromDate.getFullYear() + "-" + (fromDate.getMonth() + 1) + "-" + fromDate.getDate();
                toDate = toDate.getFullYear() + "-" + (toDate.getMonth() + 1) + "-" + toDate.getDate();

                if ($scope.employee.salesGroup != "") {
                    var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_MP_SERVICES_SRV/ZMPORDERFLOWSet?$filter=Vkgrp%20eq%20%27" + $scope.employee.salesGroup + "%27%20and%20DateFrom%20eq%20datetime%27" + fromDate + "T00:00:00%27%20and%20DateTo%20eq%20datetime%27" + toDate + "T00:00:00%27&$format=json"

                    $http.get(url)
                        .success(function (data, status) {
                            if (data) {
                                $scope.orderStatus = data.d.results;
                            } else {
                                $scope.orderStatus = [];
                            }
                            $scope.showOrderStatusHier = true;
                            generateOrderSummary();

                        }).error(onError);
                } else {
                    alert("Sales Group is empty");
                }
            }

        }


        function validateValues() {
            var fromDate = new Date($scope.IndentFromDate.val);
            var toDate = new Date($scope.IndentToDate.val);

            var todayDate = new Date();

            fromDate = new Date(fromDate.getFullYear(), fromDate.getMonth(), fromDate.getDate()); //Year, Month, Date
            toDate = new Date(toDate.getFullYear(), toDate.getMonth(), toDate.getDate()); //Year, Month, Date
            todayDate = new Date(todayDate.getFullYear(), todayDate.getMonth(), todayDate.getDate());


            if (fromDate > toDate) {
                alert("From date cannot more than To date");
                return false;
            } else if (fromDate > todayDate) {
                alert("From date cannot more than Today date");
                return false;
            } else if (toDate > todayDate) {
                alert("To date cannot more than Today date");
                return false;
            }

            return true;
        }




        $scope.showOrderSummary = function (txt) {
            for (var ii = 0; ii < $scope.orderStatus.length; ii++) {
                var tt = $scope.orderStatus[ii].Ordrno.toString() + $scope.orderStatus[ii].Matcode.toString();
                if (tt == txt) {
                    $scope.orderStatus[ii].show = true;
                } else {
                    $scope.orderStatus[ii].show = false;
                }
            }
        }

        function generateOrderSummary() {

            for (var ii = 0; ii < $scope.orderStatus.length; ii++) {
                $scope.orderStatus[ii].show = false;
                if ($scope.orderStatus[ii].Ordrdt) {
                    var tt = $scope.orderStatus[ii].Ordrdt.substring(6, $scope.orderStatus[ii].Ordrdt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].Ordrdt = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].DelDate) {
                    var tt = $scope.orderStatus[ii].DelDate.substring(6, $scope.orderStatus[ii].DelDate.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].DelDate = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].ShpmntDt) {
                    var tt = $scope.orderStatus[ii].ShpmntDt.substring(6, $scope.orderStatus[ii].ShpmntDt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].ShpmntDt = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].LoadDate) {
                    var tt = $scope.orderStatus[ii].LoadDate.substring(6, $scope.orderStatus[ii].LoadDate.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].LoadDate = dd.toString().substring(0, 15);
                }
                if ($scope.orderStatus[ii].Reqdeldt) {
                    var tt = $scope.orderStatus[ii].Reqdeldt.substring(6, $scope.orderStatus[ii].Reqdeldt.length - 2);
                    var dd = new Date(parseInt(tt));
                    $scope.orderStatus[ii].Reqdeldt = dd.toString().substring(0, 15);
                }

                $scope.orderStatus[ii].ShpmntTime = $scope.orderStatus[ii].ShpmntTime.substring(2, 4) + ":" + $scope.orderStatus[ii].ShpmntTime.substring(5, 7) + ":" + $scope.orderStatus[ii].ShpmntTime.substring(8, 10);
                $scope.orderStatus[ii].DelTime = $scope.orderStatus[ii].DelTime.substring(2, 4) + ":" + $scope.orderStatus[ii].DelTime.substring(5, 7) + ":" + $scope.orderStatus[ii].DelTime.substring(8, 10);
                $scope.orderStatus[ii].LoadTime = $scope.orderStatus[ii].LoadTime.substring(2, 4) + ":" + $scope.orderStatus[ii].LoadTime.substring(5, 7) + ":" + $scope.orderStatus[ii].LoadTime.substring(8, 10);
                $scope.orderStatus[ii].Erzet = $scope.orderStatus[ii].Erzet.substring(2, 4) + ":" + $scope.orderStatus[ii].Erzet.substring(5, 7) + ":" + $scope.orderStatus[ii].Erzet.substring(8, 10);

            }
            var prodOrderStatus = _.groupBy($scope.orderStatus, "Matcode");

            $scope.prodOrderSummary = [];
            for (var pos in prodOrderStatus) {
                var tempArr = prodOrderStatus[pos];
                var tempObj = {
                    product: "",
                    productName: "",
                    quantityDispatched: 0,
                    quantityLoading: 0,
                    quantityPending: 0
                }
                tempObj.product = prodOrderStatus[pos][0].Matcode;
                tempObj.productName = prodOrderStatus[pos][0].Matdesc;

                for (var jj = 0; jj < tempArr.length; jj++) {
                    if (tempArr[jj].Comment == "Load Dispatched") {
                        tempObj.quantityDispatched += parseFloat(tempArr[jj].Qunatity);
                    } else if (tempArr[jj].Comment == "Delivery Created" || tempArr[jj].Comment == "Shipment Created") {
                        tempObj.quantityLoading += parseFloat(tempArr[jj].Qunatity);
                    } else {
                        tempObj.quantityPending += parseFloat(tempArr[jj].Qunatity);
                    }
                }
                $scope.prodOrderSummary.push(tempObj);
            }
            $ionicLoading.hide();
        }

        function onError(data) {
            $scope.error = true;
            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'Some Internal Error Occurred'
            });
            $ionicLoading.hide();
        }

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('LpgController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {

        $scope.employee = userService.getUser();
        $scope.$on('$ionicView.enter', function () {
            $scope.employee = userService.getUser();
        });

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('CustomerDataController', function ($scope, $state, $http, $ionicLoading, $ionicModal, $ionicPopup, $timeout, $ionicPlatform, userService, $ionicHistory) {
        $scope.tabNumber = 4;
        var rspLoaded = false;
        var balLoaded = false;
        var payLoaded = false;
        $scope.$on('$ionicView.enter', function () {
            rspLoaded = false;
            balLoaded = false;
            payLoaded = false;
            $scope.employee = userService.getUser();
            $scope.roDetails = $scope.employee.roDetails;
            $scope.showRsp();
        });


        $scope.showRsp = function () {
            if (!rspLoaded) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });
                var rocode = $scope.roDetails.RO_CODE;

                var url = "https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_SP_new_SRV/ZMACUSTRSPSet?$filter=Soldto%20eq%20%27" + rocode + "%27%20&$format=json";
                $http.get(url)
                    .success(function (data, status) {
                        $scope.custRsp = data.d.results;
                        for (var i = 0; i < $scope.custRsp.length; i++) {
                            if ($scope.custRsp[i] && $scope.custRsp[i].Rsp) {
                                $scope.custRsp[i].Rsp = parseFloat($scope.custRsp[i].Rsp).toFixed(2);
                            } else {
                                $scope.custRsp[i].Rsp = "Not Available";
                            }

                            if ($scope.custRsp[i] && $scope.custRsp[i].Invamt) {
                                $scope.custRsp[i].Invamt = parseFloat($scope.custRsp[i].Invamt).toFixed(2);
                            } else {
                                $scope.custRsp[i].Invamt = "Not Available";
                            }

                        }
                        $scope.tabNumber = 1;
                        rspLoaded = true;
                        $ionicLoading.hide();
                    }).error(onError);
            } else {
                $scope.tabNumber = 1;
            }

        }
        $scope.showPayments = function () {
            if (!payLoaded) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });
                var rocode = "0000" + $scope.roDetails.RO_CODE;
                $http.get("https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_PAYMENTS_SRV/ZMACUSTPAYSet?$skip=0&$top=100&$inlinecount=allpages&$filter=Kunnr%20eq%20%27" + rocode + "%27&$format=json")
                    .success(function (data, status) {
                        if (data) {
                            $scope.custPayment = data.d.results;
                            for (i = 0; i < $scope.custPayment.length; i++) {
                                var tt = $scope.custPayment[i].Cpudt.substring(6, $scope.custPayment[i].Cpudt.length - 2);
                                var dd = new Date(parseInt(tt));
                                $scope.custPayment[i].Cpudt = dd.toString().substring(0, 15);
                            }
                        } else {
                            $scope.custPayment = {};
                        }
                        $scope.tabNumber = 2;
                        payLoaded = true;
                        $ionicLoading.hide();
                    }).error(onError);
            } else {
                $scope.tabNumber = 2;
            }

        }

        $scope.showBalances = function () {
            if (!balLoaded) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="bubbles"></ion-spinner><br/>Loading!'
                });
                $http.get("https://m.indianoil.in:8443/sap/opu/odata/sap/Z_XS_CUST_BAL_SRV/CcaBal1Set?$skip=0&$top=100&$inlinecount=allpages&$filter=Customer%20eq%20%27" + $scope.roDetails.RO_CODE + "%27&$format=json")
                    .success(function (data, status) {
                        $scope.custBalance = data.d.results;
                        for (var i = 0; i < $scope.custBalance.length; i++) {
                            if ($scope.custBalance[i].Balance > 0) {
                                $scope.custBalance[i].Balance = "(D) ₹ " + (Math.abs($scope.custBalance[i].Balance)).toString();
                            } else if ($scope.custBalance[i].Balance < 0) {
                                $scope.custBalance[i].Balance = "(C) ₹ " + (Math.abs($scope.custBalance[i].Balance)).toString();
                            } else {
                                $scope.custBalance[i].Balance = "(D) ₹ " + $scope.custBalance[i].Balance;
                            }
                        }

                        $scope.tabNumber = 3;
                        balLoaded = true;
                        $ionicLoading.hide();
                    }).error(onError);
            } else {
                $scope.tabNumber = 3;
            }

        }

        function onError() {
            $ionicLoading.hide();
            alert("Error occured");
        }

        $scope.goBack = function (view) {
            $ionicLoading.hide();
            /*
             var preView = userService.getpreviousView();
             $state.go(preView);
             */
            $backView = $ionicHistory.backView();
            $backView.go();
        }


    })

    .controller('VersionController', function ($scope, $state) {
        $scope.updateVersion = function () {
            window.open('https://play.google.com/store/apps/details?id=in.indianoil', '_system', 'location=no');
        }
    });

